"use strict";
(self["webpackChunk_anaconda_assistant"] = self["webpackChunk_anaconda_assistant"] || []).push([["style_index_js"],{

/***/ "./style/index.js":
/*!************************!*\
  !*** ./style/index.js ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _base_css__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base.css */ "./style/base.css");
/* harmony import */ var _anaconda_assistant_lib_style_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @anaconda/assistant_lib/style/index.js */ "../../lib/assistant/lib/style/index.js");




/***/ }),

/***/ "../../lib/assistant/lib/style/index.js":
/*!**********************************************!*\
  !*** ../../lib/assistant/lib/style/index.js ***!
  \**********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _base_css__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./base.css */ "../../lib/assistant/lib/style/base.css");



/***/ }),

/***/ "../../node_modules/css-loader/dist/cjs.js!./style/base.css":
/*!******************************************************************!*\
  !*** ../../node_modules/css-loader/dist/cjs.js!./style/base.css ***!
  \******************************************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../node_modules/css-loader/dist/runtime/cssWithMappingToString.js */ "../../node_modules/css-loader/dist/runtime/cssWithMappingToString.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../node_modules/css-loader/dist/runtime/api.js */ "../../node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
// Imports


var ___CSS_LOADER_EXPORT___ = _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default()));
// Module
___CSS_LOADER_EXPORT___.push([module.id, "/*\n    See the JupyterLab Developer Guide for useful CSS Patterns:\n\n    https://jupyterlab.readthedocs.io/en/stable/developer/css.html\n*/\n", "",{"version":3,"sources":["webpack://./style/base.css"],"names":[],"mappings":"AAAA;;;;CAIC","sourcesContent":["/*\n    See the JupyterLab Developer Guide for useful CSS Patterns:\n\n    https://jupyterlab.readthedocs.io/en/stable/developer/css.html\n*/\n"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),

/***/ "../../node_modules/css-loader/dist/cjs.js!../../lib/assistant/lib/style/base.css":
/*!****************************************************************************************!*\
  !*** ../../node_modules/css-loader/dist/cjs.js!../../lib/assistant/lib/style/base.css ***!
  \****************************************************************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../../node_modules/css-loader/dist/runtime/cssWithMappingToString.js */ "../../node_modules/css-loader/dist/runtime/cssWithMappingToString.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../../node_modules/css-loader/dist/runtime/api.js */ "../../node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
// Imports


var ___CSS_LOADER_EXPORT___ = _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default()));
// Module
___CSS_LOADER_EXPORT___.push([module.id, "/*\n    See the JupyterLab Developer Guide for useful CSS Patterns:\n\n    https://jupyterlab.readthedocs.io/en/stable/developer/css.html\n*/\n\n.as-widget-container {\n  min-width: 480px !important;\n  background: #f5f5f5;\n  height: 100%;\n}\n\n.as-widget-content {\n  height: 100%;\n  background: #f5f5f5;\n  color: #000;\n}\n\n.as-container {\n  background: white;\n  border-radius: 4px;\n  color: #212121;\n  display: flex;\n  flex-direction: column;\n  font-family: SF Pro, Tahoma, sans-serif;\n  height: 100%;\n  overflow: auto;\n  width: 100%;\n}\n\n.as-header-container {\n  display: flex;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  justify-content: flex-end;\n}\n\n.as-header-settings-icon {\n  height: 15px;\n  width: 15px;\n  margin-right: 16px;\n  color: #6a718a;\n  cursor: pointer;\n}\n\n.as-header-settings-text {\n  color: #3874cb;\n  font-style: normal;\n  font-weight: 510;\n  font-size: 13px;\n  line-height: 16px;\n  padding-right: 20px;\n}\n\n.as-login-container {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  margin: 50px 50px;\n  background: white;\n  color: #2C303A;\n  height: 100%;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-login-container a {\n  color: #6C5AF6;\n  text-decoration: underline;\n  cursor: pointer;\n}\n\n.as-login-header {\n  display: flex;\n  margin-bottom: 40px;\n  color: #2C303A;\n}\n\n.as-login-body,\n.as-login-footer {\n  margin-left: 15px;\n}\n\n.as-login-body {\n  flex-grow: 1;\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 24px;\n}\n\n.as-login-body ul {\n  margin: 20px 0;\n  padding: 0;\n  list-style: none;\n}\n\n.as-login-body ul li {\n  display: flex;\n  margin-bottom: 15px;\n  align-items: center;\n}\n\n.as-login-body ul li * {\n  fill: #0CCA4A;\n}\n\n.as-login-body ul li.coming-soon {\n  color: #6C5AF6;\n  margin-top: 35px;\n}\n\n.as-login-body ul li.disabled,\n.as-login-body ul li.disabled * {\n  color: #ABB1BF;\n  fill: #ABB1BF;\n}\n\n.as-create-account-button {\n  margin-bottom: 20px;\n  margin-top: 20px;\n  border-radius: 4px;\n  padding: 10px 16px;\n  background: #0CCA4A;\n  border: none;\n  color: #06262D;\n  cursor: pointer;\n  font-size: 16px;\n  font-weight: 700;\n  line-height: 24px;\n}\n\n.as-create-account-button:hover {\n  background: #4FAB4F;\n}\n\n.as-login-sign-in-text {\n  font-size: 14px;\n  font-weight: 400;\n  line-height: 17px;\n}\n\n.as-login-footer {\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 20px;\n  display: flex;\n  margin-bottom: 60px;\n}\n\n.as-login-footer svg,\n.as-login-body svg {\n  width: 17px;\n  height: 17px;\n  margin-right: 10px;\n}\n\n.as-login-footer svg {\n  width: 20px;\n  height: 20px;\n}\n.as-login-icon {\n  min-width: 30px;\n  max-width: 30px;\n  color: #31a824;\n}\n\n.as-title-text {\n  font-size: 24px;\n  font-weight: 700;\n  margin-left: 10px;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-subtitle-text {\n  font-size: 16px;\n  font-weight: 400;\n  line-height: 24px;\n}\n\n.as-sub-title-container {\n  display: flex;\n  gap: 5px;\n  width: 80%;\n  color: #2c303a;\n  background: #43b0491f;\n  padding: 10px 12px;\n  border-radius: 8px;\n  margin-top: 25px;\n}\n\n.as-home-screen-header {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  margin-bottom: 10px;\n}\n\n.as-home-screen-container {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  padding-left: 20px;\n  padding-right: 20px;\n  background: white;\n}\n\n.as-home-screen-icon {\n  width: 80px;\n  color: #31a824;\n}\n\n.as-sub-title-text {\n  font-size: 14px;\n  line-height: 20px;\n  font-weight: 400;\n  text-align: center;\n}\n\n.as-home-screen-body {\n  font-size: 13px;\n}\n\n.as-home-screen-section {\n  display: flex;\n  align-items: center;\n  font-size: 13px;\n  font-weight: 590;\n  letter-spacing: 0.02em;\n  margin-top: 20px;\n  margin-bottom: 10px;\n}\n\n.as-home-screen-df-icon-container {\n  width: 26px;\n  height: 26px;\n  background: #e9e6fe;\n  border-radius: 100px;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  margin-right: 10px;\n}\n\n.as-home-screen-df-icon {\n  width: 12px;\n  height: 12px;\n  color: #6c5af6;\n}\n\n.as-home-screen-code-icon-container {\n  width: 26px;\n  height: 26px;\n  background: rgba(0, 178, 255, 0.1);\n  border-radius: 100px;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  margin-right: 10px;\n}\n\n.as-home-screen-code-icon {\n  width: 13px;\n  color: #00b2ff;\n}\n\n.as-home-screen-chat-starter {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  border: 1px solid #e6e6e6;\n  margin-bottom: 3px;\n  border-radius: 8px;\n  padding: 9px 12px 9px 12px;\n  cursor: pointer;\n}\n\n.as-home-screen-chat-starter:hover {\n  background: rgba(33, 33, 33, 0.05);\n}\n\n.as-home-screen-starter-icon {\n  width: 8px;\n  height: 12px;\n  color: rgba(33, 33, 33, 0.5);\n}\n\n.as-version-text {\n  color: #bdbdbd;\n  font-size: 11px;\n  margin-top: 4px;\n  margin-left: 10px;\n}\n\n.as-graph-selector-container {\n  display: flex;\n  flex-direction: column;\n  font-size: 13px;\n  padding-left: 20px;\n  padding-right: 20px;\n  margin-bottom: 20px;\n}\n\n.as-graph-selector-message-container {\n  display: flex;\n  align-items: center;\n  height: 50px;\n  margin-top: 5px;\n  margin-bottom: 8px;\n}\n\n.as-code-share-warning-message,\n.as-dataframe-select-warning-message {\n  margin-bottom: 20px;\n  color: #757575;\n  background: #fcfccc;\n  padding: 10px;\n  font-size: 11px;\n  border-radius: 4px;\n  border: 1px solid #ebebbe;\n  display: flex;\n}\n\n.as-warning-icon-wrapper {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  padding: 0 12px 0 3px;\n}\n\n.as-warning-icon {\n  width: 23px;\n  color: #ffba0a;\n}\n\n.as-dataframe-select {\n  margin: 0;\n  box-sizing: border-box;\n  appearance: none;\n  background-color: white;\n  border: 1px solid #e0e0e0;\n  border-radius: 4px;\n  display: inline-block;\n  font: inherit;\n  font-size: 13px;\n  height: 40px;\n  line-height: 1em;\n  padding: 0.5em 3.5em 0.5em 1em;\n  background-image: linear-gradient(45deg, transparent 50%, gray 50%),\n    linear-gradient(135deg, gray 50%, transparent 50%),\n    linear-gradient(to right, #ccc, #ccc);\n  background-position: calc(100% - 20px) calc(1em + 4px),\n    calc(100% - 15px) calc(1em + 4px), calc(100% - 2.5em) 9px;\n  background-size: 5px 5px, 5px 5px, 1px 20px;\n  background-repeat: no-repeat;\n}\n\nselect:invalid {\n  color: gray;\n}\n\n.as-get-code-button {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  padding: 0.35em 1.2em;\n  border: 0.1em solid #ffffff;\n  margin-top: 16px;\n  height: 40px;\n  border-radius: 4px;\n  box-sizing: border-box;\n  text-decoration: none;\n  font-size: 13px;\n  font-weight: 300;\n  color: #06262d;\n  text-align: center;\n  transition: all 0.5s;\n  background: #0cca4a;\n}\n\n.as-get-code-button.disabled {\n  background: #bdbdbd;\n}\n\n.as-get-code-button:hover {\n  background-color: #4fab4f;\n  cursor: pointer;\n}\n\n.as-get-code-button:hover.disabled {\n  cursor: not-allowed;\n  background: #bdbdbd;\n}\n\n.as-get-code-button-icon {\n  width: 16px;\n  height: 16px;\n  margin-right: 10px;\n}\n\n.as-no-dataframe-container {\n  display: flex;\n  flex-direction: column;\n  background: #f7f7f7;\n  border-radius: 4px;\n  padding: 20px 10px;\n}\n\n.as-no-dataframe-heading {\n  font-size: 14px;\n  font-weight: lighter;\n  margin-bottom: 20px;\n}\n\n.as-no-dataframe-text {\n  font-size: 12px;\n  margin-bottom: 10px;\n}\n\n.as-no-dataframe-link {\n  display: inline;\n  color: blue;\n  text-decoration: underline;\n}\n\n.as-no-dataframe-link:hover {\n  color: darkblue;\n  text-decoration: underline;\n}\n\n/*Main Chat Screen*/\n\n.as-chat-header-container {\n  display: flex;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-chat-header-title-container {\n  flex: 1;\n  display: flex;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  border-bottom: 1px solid rgba(85, 85, 85, 0.05);\n}\n\n.as-chat-header-settings-container {\n  display: flex;\n  justify-content: flex-end;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  width: 50px;\n}\n\n.as-chat-header-text-icon {\n  display: flex;\n  justify-content: center;\n}\n\n.as-chat-header-main-icon {\n  width: 20px;\n  height: 15px;\n  color: #31a824;\n  padding-left: 15px;\n  margin-right: 7px;\n}\n\n.as-chat-header-main-text {\n  color: #2c303a;\n  font-style: normal;\n  font-weight: 700;\n  font-size: 16px;\n  line-height: 24px;\n}\n\n.as-chat-header-version-text {\n  color: #bdbdbd;\n  font-size: 11px;\n  padding-left: 10px;\n  padding-right: 10px;\n  margin-top: 2px;\n}\n\n.as-chat-header-pro-tier-text {\n  color: white;\n  font-size: 11px;\n  padding-left: 10px;\n  padding-right: 10px;\n  margin-top: 2px;\n  background: #31a824;\n  border-radius: 4px;\n  padding: 3px 6px 1px;\n}\n\n.as-chat-main-section {\n  overflow-y: scroll;\n  height: 100%;\n  display: flex;\n  flex-direction: column;\n}\n\n.as-chat-message-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.as-user-chat-message-buttons-container {\n  display: flex;\n  flex-direction: column;\n  background: #e9e6fe;\n}\n\n.as-user-chat-message-container {\n  display: flex;\n  flex-direction: column;\n  align-items: start;\n  padding: 10px 20px 5px;\n  min-height: 50px;\n}\n\n.as-user-chat-message-buttons-container:first-child\n  .as-user-chat-message-container,\n.as-user-chat-message-buttons-container:nth-child(2)\n  .as-user-chat-message-container {\n  flex-direction: row;\n  align-items: center;\n  padding: 5px 20px;\n}\n\n.as-user-chat-message-icon-container {\n  background: #6c5af6;\n  padding: 6px 7px;\n  margin-right: 10px;\n  border-radius: 4px;\n}\n\n.as-user-chat-message-buttons-container:not(:first-child):not(:nth-child(2))\n  .as-user-chat-message-icon-container {\n  margin-bottom: 5px;\n}\n\n.as-user-chat-message-icon {\n  width: 14px;\n  height: 16px;\n  color: white;\n}\n\n.as-user-chat-message-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n  word-break: break-word;\n  padding: 6px 0;\n  white-space: pre-wrap;\n  margin-left: 1px;\n}\n\n.as-user-chat-message-text-bold {\n  font-size: 13px;\n  font-weight: bold;\n  font-style: normal;\n  margin-left: 5px;\n}\n\n.as-code-container {\n}\n\n.as-code-message-container {\n  display: flex;\n  align-items: center;\n  height: 50px;\n  padding-left: 20px;\n  padding-right: 20px;\n}\n\n.as-code-message-icon-container {\n  background: #4fab4f;\n  border-radius: 4px;\n  margin-right: 10px;\n  padding: 8px 4px 5px 4px;\n}\n\n.as-code-message-icon {\n  width: 20px;\n  height: 16px;\n  color: white;\n}\n\n.as-code-message-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n}\n\n.as-code-loading {\n  font-size: 13px;\n}\n\n.as-code-loading:after {\n  overflow: hidden;\n  display: inline-block;\n  vertical-align: bottom;\n  -webkit-animation: ellipsis steps(4, end) 1200ms infinite;\n  animation: ellipsis steps(4, end) 1200ms infinite;\n  content: \"\\2026\"; /* ascii code for the ellipsis character */\n  width: 0;\n}\n\n.as-export-chat-container {\n  display: flex;\n  align-items: center;\n  padding: 0 20px;\n  min-height: 50px;\n  background: linear-gradient(white, white, white, #fdfdfd, #fafafa, #f8f8f8);\n  justify-content: center;\n  color: #ccc;\n  gap: 10px;\n  font-size: 12px;\n  cursor: pointer;\n  margin-top: auto;\n}\n\n.as-export-chat-container:hover {\n  color: #6c5af6;\n  text-shadow: 1px 1px 0 white;\n}\n\n.as-export-chat-container svg {\n  height: 12px;\n}\n\n@keyframes ellipsis {\n  to {\n    width: 1.25em;\n  }\n}\n\n@-webkit-keyframes ellipsis {\n  to {\n    width: 1.25em;\n  }\n}\n\n.as-code-generate-container {\n  width: 100%;\n  display: flex;\n  justify-content: space-between;\n}\n\n.as-code-generate-refresh {\n  color: rgb(56, 116, 203);\n  cursor: pointer;\n}\n\n.as-code-generate-refresh-disabled {\n  color: rgb(56, 116, 203, 0.5);\n  cursor: not-allowed;\n}\n\n.as-code-block {\n  padding-left: 20px;\n  padding-right: 20px;\n}\n\n.as-text-block {\n  padding-left: 21px;\n  padding-right: 20px;\n  font-size: 13px;\n  line-height: 20px;\n  color: #20262f;\n  white-space: pre-wrap;\n  word-break: break-word;\n}\n\n.as-code-error-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n}\n\n.as-code-error-panel {\n  margin-left: 20px;\n  margin-right: 20px;\n  border-radius: 4px;\n  background: #fef1f1;\n  display: flex;\n  padding: 16px;\n}\n\n.as-code-error-icon {\n  width: 16px;\n  height: 16px;\n  min-width: 16px;\n  min-height: 16px;\n  color: #f44336;\n  margin-right: 8px;\n}\n\n.as-code-error-panel-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n  color: #d60000;\n}\n\n.as-code-error-footer {\n  display: flex;\n  margin-left: 20px;\n  margin-top: 8px;\n}\n\n.as-code-retry-button {\n  display: flex;\n  border: none;\n  background: #3d3d3d;\n  justify-content: center;\n  align-items: center;\n  border-radius: 4px;\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n  padding: 8px;\n  margin-right: 8px;\n  color: white;\n  cursor: pointer;\n}\n\n.as-code-retry-icon,\n.as-code-copy-icon {\n  width: 16px;\n  height: 16px;\n  margin-right: 8px;\n}\n\n.as-code-error-token-limit .as-code-error-panel,\n.as-code-error-upgrade .as-code-error-panel {\n  background: #43b0491f;\n  margin-top: 20px;\n  margin-bottom: 20px;\n}\n\n.as-code-error-token-limit .as-code-error-panel-text a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-code-error-token-limit .as-code-error-panel-text,\n.as-code-error-upgrade .as-code-error-panel-text {\n  color: #2c303a;\n  margin-left: 10px;\n  font-size: 13px;\n}\n\n.as-code-error-upgrade .as-code-error-icon {\n  min-width: 42px;\n  color: #31a824;\n  margin-right: 8px;\n}\n\n.as-code-error-token-limit .as-code-error-icon {\n  min-width: 42px;\n  color: #31a824;\n  margin-right: 4px;\n  margin-top: 2px;\n}\n\n.as-code-error-token-limit .as-code-error-token-limit-restart-button svg {\n  width: 12px;\n  margin-right: 4px;\n}\n\n.as-code-error-token-limit .as-code-retry-button,\n.as-code-error-upgrade .as-code-retry-button {\n  background: #4fab4f;\n  color: white;\n  font-size: 16px;\n  margin-right: 20px;\n  margin-bottom: 40px;\n}\n\n.as-code-error-token-limit .as-code-retry-button:hover,\n.as-code-error-upgrade .as-code-retry-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-instruction-container {\n  display: flex;\n  height: 50px;\n  padding-left: 20px;\n  padding-top: 8px;\n  padding-right: 20px;\n  margin-bottom: 10px;\n}\n\n.as-instruction-input-form {\n  display: flex;\n  align-items: end;\n  width: 100%;\n  min-height: 36px;\n  background: #ffffff;\n  border: 1px solid #e0e0e0;\n  box-shadow: 0 0 8px rgba(0, 0, 0, 0.07);\n  border-radius: 8px;\n  padding: 7px 6px 6px 16px;\n  margin-bottom: 10px;\n  max-height: 215px;\n}\n\n.as-instruction-input-textarea {\n  border: none;\n  resize: none;\n  flex: 1;\n  font-family: Tahoma, sans-serif;\n  background: canvas;\n  font-size: 12px;\n  line-height: 16px;\n  min-height: 16px;\n  max-height: 200px;\n  margin-bottom: 8px;\n}\n\n.as-instruction-input-textarea:disabled {\n  cursor: not-allowed;\n}\n\n.as-instruction-input-textarea::placeholder:disabled {\n  cursor: not-allowed;\n  color: red;\n}\n.as-instruction-input-textarea:disabled::placeholder {\n  color: rgba(211, 211, 211, 0.5);\n}\n\n.as-instruction-input-textarea:focus {\n  border: none;\n  outline: none;\n}\n\n.as-instruction-attach-context-button {\n  border: none;\n  background: inherit;\n  padding: 0px;\n  color: #6c5af6;\n  cursor: pointer;\n  display: flex;\n  gap: 6px;\n  font-size: 13px;\n}\n.as-instruction-attach-context-button:hover {\n  filter: brightness(1.2);\n}\n.as-instruction-attach-context-button:disabled {\n  color: #999;\n  cursor: not-allowed;\n}\n\n.as-instruction-submit-button {\n  border: none;\n  background: #4fab4f;\n  color: white;\n  border-radius: 4px;\n  height: 100%;\n  cursor: pointer;\n  padding: 0 8px;\n}\n.as-instruction-submit-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-instruction-submit-button:disabled {\n  background: #43b04933;\n  color: #31a824;\n  cursor: not-allowed;\n}\n\n.as-instruction-send-icon {\n  width: 14px;\n  padding-left: 6px;\n  padding-right: 6px;\n}\n\n.as-chat-footer {\n  display: flex;\n  padding-left: 20px;\n  padding-right: 20px;\n  padding-top: 2px;\n  align-items: center;\n}\n\n.as-chat-footer-container {\n  border-top: 1px solid #e0e0e0;\n  background: #f5f5f5;\n  padding-bottom: 16px;\n  z-index: 2;\n}\n\n.as-chat-reset-container {\n  transition: opacity 0.5s;\n  display: flex;\n  align-items: end;\n  color: #6c5af6;\n  cursor: pointer;\n}\n\n.as-chat-reset-container-disabled {\n  color: rgb(183, 192, 206);\n  cursor: not-allowed;\n}\n\n.as-chat-reset-icon {\n  width: 12px;\n  margin-right: 4px;\n  margin-bottom: -2px;\n}\n\n.as-chat-reset-text {\n  font-size: 11px;\n}\n\n.as-chat-token-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.as-chat-token-bar-container {\n  display: flex;\n  width: 72px;\n  margin-right: 16px;\n  margin-bottom: 6px;\n  background: #e1e1e1;\n}\n\n.as-chat-token-filled {\n  height: 7px;\n  background: linear-gradient(270deg, #ffb84f 0%, #76dd5c 100%), #80b241;\n  transition: width 1s ease-in-out;\n}\n\n.as-chat-token-text {\n  display: flex;\n  font-size: 11px;\n  margin-right: 4px;\n  color: rgb(33, 33, 33, 0.5);\n}\n\n.as-chat-token-count {\n  display: flex;\n  font-weight: bold;\n  padding-left: 5px;\n  padding-right: 5px;\n}\n\n.as-user-chat-message-buttons-container .as-message-buttons-container {\n  margin-top: 0px;\n}\n\n.as-user-chat-message-buttons-container\n  .as-message-buttons-container\n  *:not(.as-code-feedback-modal)\n  svg {\n  color: #ceced4;\n  cursor: pointer;\n}\n\n.as-message-buttons-container {\n  display: flex;\n  align-items: center;\n  padding: 0px 20px 5px;\n  margin-top: 15px;\n}\n\n.as-message-export-icon-container svg,\n.as-code-feedback-thumbs-icon svg {\n  width: 14px;\n  cursor: pointer;\n  color: #e0e0e0;\n}\n\n.as-code-feedback-thumbs-icon svg {\n  margin-left: 8px;\n}\n\ndiv\n  .as-message-buttons-container\n  *:not(.as-code-feedback-modal) svg:hover {\n  color: #9ca3af;\n}\n\n.as-message-button-trash-icon-container {\n  margin-left: auto;\n}\n\n.as-code-feedback-thumbs-icons {\n  display: flex;\n  margin-left: auto;\n}\n\n.as-code-feedback-thumbs-icon-completed {\n  width: 16px;\n  height: 16px;\n  margin-right: 8px;\n  color: #e0e0e0;\n}\n\n.as-code-feedback-thumbs-completed-beat {\n  animation: as-code-thumbs-beat 0.5s infinite;\n  animation-duration: 0.5s;\n  animation-iteration-count: 1;\n  animation-timing-function: ease-in-out;\n}\n\n.as-code-feedback-thumbs-up svg {\n  color: #14d662;\n}\n\n.as-code-feedback-thumbs-down svg {\n  color: #f29c9c;\n}\n\n.as-code-thumbs-initial-beat {\n  animation: as-code-thumbs-beat 1s infinite;\n  animation-duration: 1s;\n  animation-iteration-count: 2;\n  animation-timing-function: ease-in-out;\n}\n\n@keyframes as-code-thumbs-beat {\n  0%,\n  90% {\n    transform: scale(1);\n  }\n  45% {\n    transform: scale(1.25);\n  }\n}\n\n#as-arrow,\n#as-arrow::before {\n  position: absolute;\n  width: 8px;\n  height: 8px;\n  background: #caecca;\n}\n\n#as-arrow {\n  visibility: hidden;\n}\n\n#as-arrow::before {\n  visibility: visible;\n  background: #caecca;\n  content: \"\";\n  transform: rotate(45deg);\n  bottom: 4px;\n}\n\n.as-code-feedback-modal {\n  padding: 15px;\n  background: #caecca;\n  border: 1px solid #c4d4b8;\n  color: rgb(90, 86, 97);\n  border-radius: 4px;\n}\n\n.as-code-feedback-modal-header {\n  display: flex;\n  align-items: center;\n  margin-bottom: 15px;\n}\n\n.as-code-feedback-header-positive-icon {\n  width: 20px;\n  height: 20px;\n  margin-right: 10px;\n}\n\n.as-code-feedback-header-negative-icon {\n  width: 20px;\n  height: 20px;\n  margin-right: 10px;\n  margin-bottom: -6px;\n  transform: rotate(180deg);\n}\n\n.as-code-feedback-modal-title {\n  font-size: 16px;\n}\n\n.as-code-feedback-text-area {\n  min-height: 70px;\n  height: 70px;\n  align-items: center;\n  display: flex;\n  background: #f5faf6;\n  border: 1px solid #b1d2aa;\n  border-radius: 4px;\n  padding: 6px 5px 3px 10px;\n  margin-bottom: 5px;\n}\n\n.as-code-feedback-text-area textarea {\n  background: inherit;\n}\n\n.as-code-feedback-form {\n}\n\n.as-code-feedback-button-container {\n  display: flex;\n  justify-content: flex-end;\n}\n\n.as-code-feedback-submit-button {\n  border: none;\n  font-size: 12px;\n  background: #4fab4f;\n  border-radius: 4px;\n  padding-left: 12px;\n  padding-right: 12px;\n  margin-top: 5px;\n  height: 32px;\n  color: white;\n  cursor: pointer;\n}\n\n.as-code-feedback-submit-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-settings-container {\n  display: flex;\n  flex-direction: column;\n  margin-top: 20px;\n  margin-bottom: 40px;\n  overflow-y: scroll;\n}\n\n.as-setting-control-container {\n  border-bottom: 1px solid rgba(85, 85, 85, 0.05);\n  padding: 20px;\n  height: -webkit-fill-available;\n  overflow-y: scroll;\n}\n\n.as-setting-control-title {\n  font-size: 14px;\n  font-weight: bold;\n  margin-bottom: 10px;\n}\n\n.as-setting-control-inner-container {\n  display: flex;\n  align-items: center;\n  justify-content: end;\n  gap: 20px;\n  font-size: 13px;\n  margin: 20px 0;\n}\n\n.as-setting-control-description {\n  max-width: 77%;\n}\n\n.as-settings-template-container {\n  padding-top: 20px;\n}\n\n.as-settings-sub-header-container {\n  font-size: 12px;\n  font-weight: lighter;\n  color: #9ca3af;\n  margin-bottom: 25px;\n  display: flex;\n  flex-direction: column;\n}\n\n.as-settings-sub-header {\n}\n\n.as-setting-container {\n  display: flex;\n  flex-direction: column;\n  margin-bottom: 20px;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit {\n  max-width: 100%;\n  flex-grow: 1;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit\n  svg {\n  width: 12px;\n  margin-right: 4px;\n  display: inline-block;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit\n  .as-code-upgrade-button {\n  align-items: center;\n  background: #4fab4f;\n  border-radius: 4px;\n  border: none;\n  color: white;\n  cursor: pointer;\n  display: flex;\n  font-size: 16px;\n  font-style: normal;\n  justify-content: center;\n  margin-bottom: 5px;\n  margin-top: 15px;\n  margin-left: auto;\n  margin-right: 20px;\n  padding: 8px;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit\n  .as-code-upgrade-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-setting-control-description.as-setting-logout {\n  max-width: 100%;\n}\n\n.as-setting-control-description .as-logout-button {\n  color: #444;\n  align-items: center;\n  border-radius: 4px;\n  border: none;\n  cursor: pointer;\n  display: flex;\n  font-size: 16px;\n  font-style: normal;\n  justify-content: center;\n  padding: 8px;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-code-run-button,\n.as-code-replace-button,\n.as-code-copy-button {\n  display: flex;\n  border: none;\n  background: #e9e6fe;\n  color: #6c5af6;\n  justify-content: center;\n  align-items: center;\n  border-radius: 4px;\n  font-size: 13px;\n  font-weight: 400;\n  font-style: normal;\n  padding: 8px;\n  cursor: pointer;\n  transition: 0.5s ease-out;\n  -moz-transition: 0.5s ease-out;\n  -webkit-transition: 0.5s ease-out;\n}\n\n.as-code-run-button.disabled,\n.as-code-replace-button.disabled,\n.as-code-copy-button.disabled {\n  background: #f5f5f5;\n  color: #999;\n  cursor: not-allowed;\n}\n\n.as-code-copy-button {\n  margin-left: auto;\n}\n.as-code-run-button.clicked,\n.as-code-replace-button.clicked,\n.as-code-copy-button.clicked {\n  background: rgba(67, 176, 73, 0.5);\n  color: black;\n}\n\n.as-code-run-button:hover:not(.clicked):not(.disabled),\n.as-code-replace-button:hover:not(.clicked):not(.disabled),\n.as-code-copy-button:hover:not(.clicked):not(.disabled) {\n  background: #e1ddfd;\n}\n\n.as-code-replace-button {\n  flex-grow: 1;\n}\n\n.as-run-code-container {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  padding-left: 20px;\n  padding-right: 20px;\n  min-height: 16px;\n  margin-bottom: 8px;\n  gap: 10px;\n}\n\n.as-access-inner-container {\n  padding: 0px 20px 0px 20px;\n}\n\n.as-access-inner-container-buttons {\n  padding: 0px 20px 0px 20px;\n  display: flex;\n  justify-content: space-between;\n}\n\n.as-access-header {\n  font-size: 24px;\n  font-weight: lighter;\n  margin-bottom: 10px;\n  margin-top: 10px;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-access-text {\n  font-size: 13px;\n  font-weight: normal;\n}\n\n.as-access-inner-container a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-terms-button,\n.as-access-button,\n.as-access-inner-container-buttons .as-logout-button {\n  margin-top: 35px;\n  border-radius: 4px;\n  padding: 12px;\n  background: #4fab4f;\n  border: none;\n  color: white;\n  cursor: pointer;\n  font-size: 16px;\n}\n\n.as-terms-button {\n  margin-left: auto;\n}\n\n\n.as-terms-button:hover {\n  background: #0cca4a;\n  color: black;\n}\n\n.as-terms-error-button {\n  border-radius: 4px;\n  padding: 12px;\n  background: #3874cb;\n  border: none;\n  color: white;\n  cursor: pointer;\n}\n\n.as-terms-error {\n  border-radius: 6px;\n  /* Transparent red */\n  background-color: rgba(255, 0, 0, 0.1);\n  padding: 10px;\n  font-size: 12px;\n}\n\n.as-terms-error-text {\n  color: #ff0000;\n  font-size: 12px;\n  margin-bottom: 10px;\n}\n\n.as-sub-header-container {\n  height: 40px;\n  min-height: 40px;\n  display: flex;\n  align-items: center;\n  border-bottom: 1px solid #d9d9d9;\n  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.07);\n}\n\n.as-sub-header-container.as-has-previous-chat {\n  border-bottom: none;\n  box-shadow: none;\n}\n\n.as-sub-header-menu-icon-wrapper {\n  display: flex;\n  align-items: center;\n  margin-left: 17px;\n  font-size: 12px;\n  color: #6a718a;\n  cursor: pointer;\n  user-select: none;\n  -webkit-user-select: none;\n}\n\n.as-sub-header-menu-icon {\n  width: 14px;\n  margin-top: 3px;\n  margin-right: 8px;\n}\n\n.as-sub-header-title-container {\n  display: flex;\n  flex: 1;\n  justify-content: center;\n  align-items: center;\n}\n\n.as-sub-header-title {\n  font-size: 13px;\n}\n\n.as-sub-header-new-chat-icon-wrapper {\n  display: flex;\n  align-items: center;\n  font-size: 12px;\n  margin-right: 15px;\n  padding: 5px 12px;\n  border-radius: 4px;\n  background: #4fab4f;\n  color: white;\n  cursor: pointer;\n  user-select: none;\n  -webkit-user-select: none;\n}\n\n.as-sub-header-new-chat-icon-wrapper:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-sub-header-new-chat-icon-wrapper.disabled {\n  background: #43b04933;\n  color: #31a824;\n  cursor: default;\n}\n\n.as-sub-header-new-chat-icon {\n  width: 14px;\n  padding-right: 7px;\n}\n\n.as-sub-header-link-text {\n  font-size: 13px;\n  color: #6a718a;\n}\n\n.as-sub-header-link-text a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-back-button-container {\n  background-color: #e9e6fe;\n  height: 30px;\n  padding: 0 18px;\n  display: flex;\n  align-items: center;\n  border-bottom: 1px solid #d9d9d9;\n  color: #778;\n}\n\n.as-back-button-icon {\n  width: 14px;\n  padding-top: 4px;\n  padding-left: 2px;\n  padding-right: 2px;\n  color: #6c5af6;\n  cursor: pointer;\n}\n\n.as-back-button-title-container {\n  width: 100%;\n  display: grid;\n  text-align: center;\n}\n\n.as-back-button-title {\n  font-size: 12px;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  min-width: 0;\n}\n\n.as-generate-code-option-container {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  border: 1px solid #e0e0e0;\n  border-radius: 4px;\n  padding: 12px;\n  margin-bottom: 8px;\n  cursor: pointer;\n}\n.as-generate-code-option-container:hover {\n  background: rgba(33, 33, 33, 0.05);\n}\n\n.as-menu-drawer-container {\n  z-index: 10;\n  position: absolute;\n}\n\n.as-menu-background {\n  position: absolute;\n  top: 90px;\n  background: gray;\n  transition: opacity 0.5s ease-in-out;\n  height: 100vh;\n}\n\n.as-menu-drawer {\n  position: absolute;\n  height: calc(100vh - 90px);\n  background: white;\n  opacity: 1;\n  border-right: 1px solid #999;\n}\n\n.as-menu-drawer.open {\n  box-shadow: 4px 0 8px rgba(0, 0, 0, 0.1);\n}\n\n.as-history-menu {\n  padding-left: 10px;\n  padding-right: 10px;\n  font-size: 14px;\n  height: 100%;\n  z-index: 10;\n}\n.as-history-menu-header {\n  margin-top: 12px;\n  margin-bottom: 12px;\n  margin-left: 10px;\n  font-size: 14px;\n  color: rgb(33, 33, 33, 0.5);\n}\n.as-history-menu-container {\n  display: flex;\n  flex-direction: column;\n}\n.as-history-menu-item {\n  height: 40px;\n  border-radius: 8px;\n  display: flex;\n  align-items: center;\n  padding-left: 10px;\n  padding-right: 10px;\n  margin-bottom: 5px;\n}\n.as-history-menu-item-active {\n  background: #43b0491f;\n}\n\n.as-history-menu-item:hover {\n  background: #f3f4f6;\n  cursor: pointer;\n}\n\n.as-history-menu-item-icon {\n  width: 13px;\n  height: 13px;\n  min-width: 13px;\n  margin-top: 2px;\n  margin-right: 8px;\n  color: #43b049;\n}\n\n.as-history-menu-item-text {\n  overflow: hidden;\n  font-size: 13px;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n}\n\n.as-history-menu-item-close-icon {\n  height: 13px;\n  color: #6a718a;\n  cursor: pointer;\n  display: none;\n  margin-left: auto;\n}\n\n.as-history-menu-item-close-icon svg {\n  width: 10px;\n}\n\n.as-history-menu-item:hover .as-history-menu-item-close-icon {\n  display: block;\n}\n\n.as-history-no-chats {\n  height: calc(100% - 100px);\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  justify-content: center;\n  font-size: 14px;\n  color: rgb(33, 33, 33, 0.3);\n}\n\n.as-popup-outer-container {\n  position: fixed;\n  width: 480px;\n  right: 32px;\n  bottom: 80px;\n}\n\n.as-error-popup {\n  position: absolute;\n  border: 2px solid rgba(219, 105, 112, 0.4);\n  box-shadow: 0 0 16px rgba(0, 0, 0, 0.1);\n  border-radius: 8px;\n  background: white;\n  z-index: 1;\n}\n\n.as-explain-popup {\n  position: absolute;\n  border: 1px solid rgba(224, 224, 224, 0.8);\n  box-shadow: 0 0 16px rgba(0, 0, 0, 0.1);\n  border-radius: 8px;\n  background: white;\n  z-index: 1;\n}\n\n.as-popup-container {\n  padding: 0 16px;\n  height: 100%;\n  display: flex;\n  flex-direction: column;\n}\n\n.as-popup-header {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  font-size: 13px;\n  font-weight: bold;\n  padding-top: 10px;\n  padding-bottom: 10px;\n  color: #212121;\n}\n\n.as-popup-logo {\n  display: flex;\n  align-items: center;\n  color: #2c303a;\n  font-style: normal;\n  font-weight: 700;\n  font-size: 14px;\n}\n\n.as-popup-icon-container {\n  background: #4fab4f;\n  border-radius: 4px;\n  margin-right: 10px;\n  padding: 8px 4px 5px 4px;\n}\n\n.as-popup-icon {\n  width: 20px;\n  height: 16px;\n  color: white;\n}\n\n.as-popup-close-icon {\n  width: 14px;\n  color: rgb(33, 33, 33, 0.5);\n  cursor: pointer;\n}\n\n.as-popup-close-icon:hover {\n  color: rgb(33, 33, 33, 0.8);\n}\n\n.as-popup-buttons {\n  display: flex;\n  flex-direction: column;\n  gap: 5px;\n  padding-bottom: 15px;\n}\n\n.as-popup-button {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  background: white;\n  border: 1px solid #e6e6e6;\n  margin-bottom: 3px;\n  border-radius: 8px;\n  padding: 9px 12px 9px 12px;\n  cursor: pointer;\n}\n\n.as-popup-button:hover {\n  background: rgba(33, 33, 33, 0.05);\n}\n\n.as-popup-button-icon {\n  width: 8px;\n  height: 12px;\n  color: rgba(33, 33, 33, 0.5);\n}\n\n.as-popup-buttons-section {\n  display: flex;\n  align-items: center;\n  font-size: 13px;\n  font-weight: 590;\n  letter-spacing: 0.02em;\n}\n", "",{"version":3,"sources":["webpack://./../../lib/assistant/lib/style/base.css"],"names":[],"mappings":"AAAA;;;;CAIC;;AAED;EACE,2BAA2B;EAC3B,mBAAmB;EACnB,YAAY;AACd;;AAEA;EACE,YAAY;EACZ,mBAAmB;EACnB,WAAW;AACb;;AAEA;EACE,iBAAiB;EACjB,kBAAkB;EAClB,cAAc;EACd,aAAa;EACb,sBAAsB;EACtB,uCAAuC;EACvC,YAAY;EACZ,cAAc;EACd,WAAW;AACb;;AAEA;EACE,aAAa;EACb,gBAAgB;EAChB,YAAY;EACZ,mBAAmB;EACnB,yBAAyB;AAC3B;;AAEA;EACE,YAAY;EACZ,WAAW;EACX,kBAAkB;EAClB,cAAc;EACd,eAAe;AACjB;;AAEA;EACE,cAAc;EACd,kBAAkB;EAClB,gBAAgB;EAChB,eAAe;EACf,iBAAiB;EACjB,mBAAmB;AACrB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,uBAAuB;EACvB,iBAAiB;EACjB,iBAAiB;EACjB,cAAc;EACd,YAAY;EACZ,gCAAgC;AAClC;;AAEA;EACE,cAAc;EACd,0BAA0B;EAC1B,eAAe;AACjB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,cAAc;AAChB;;AAEA;;EAEE,iBAAiB;AACnB;;AAEA;EACE,YAAY;EACZ,eAAe;EACf,gBAAgB;EAChB,iBAAiB;AACnB;;AAEA;EACE,cAAc;EACd,UAAU;EACV,gBAAgB;AAClB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,mBAAmB;AACrB;;AAEA;EACE,aAAa;AACf;;AAEA;EACE,cAAc;EACd,gBAAgB;AAClB;;AAEA;;EAEE,cAAc;EACd,aAAa;AACf;;AAEA;EACE,mBAAmB;EACnB,gBAAgB;EAChB,kBAAkB;EAClB,kBAAkB;EAClB,mBAAmB;EACnB,YAAY;EACZ,cAAc;EACd,eAAe;EACf,eAAe;EACf,gBAAgB;EAChB,iBAAiB;AACnB;;AAEA;EACE,mBAAmB;AACrB;;AAEA;EACE,eAAe;EACf,gBAAgB;EAChB,iBAAiB;AACnB;;AAEA;EACE,eAAe;EACf,gBAAgB;EAChB,iBAAiB;EACjB,aAAa;EACb,mBAAmB;AACrB;;AAEA;;EAEE,WAAW;EACX,YAAY;EACZ,kBAAkB;AACpB;;AAEA;EACE,WAAW;EACX,YAAY;AACd;AACA;EACE,eAAe;EACf,eAAe;EACf,cAAc;AAChB;;AAEA;EACE,eAAe;EACf,gBAAgB;EAChB,iBAAiB;EACjB,gCAAgC;AAClC;;AAEA;EACE,eAAe;EACf,gBAAgB;EAChB,iBAAiB;AACnB;;AAEA;EACE,aAAa;EACb,QAAQ;EACR,UAAU;EACV,cAAc;EACd,qBAAqB;EACrB,kBAAkB;EAClB,kBAAkB;EAClB,gBAAgB;AAClB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,mBAAmB;EACnB,mBAAmB;AACrB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,uBAAuB;EACvB,kBAAkB;EAClB,mBAAmB;EACnB,iBAAiB;AACnB;;AAEA;EACE,WAAW;EACX,cAAc;AAChB;;AAEA;EACE,eAAe;EACf,iBAAiB;EACjB,gBAAgB;EAChB,kBAAkB;AACpB;;AAEA;EACE,eAAe;AACjB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,eAAe;EACf,gBAAgB;EAChB,sBAAsB;EACtB,gBAAgB;EAChB,mBAAmB;AACrB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,mBAAmB;EACnB,oBAAoB;EACpB,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,kBAAkB;AACpB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,cAAc;AAChB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,kCAAkC;EAClC,oBAAoB;EACpB,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,kBAAkB;AACpB;;AAEA;EACE,WAAW;EACX,cAAc;AAChB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,8BAA8B;EAC9B,yBAAyB;EACzB,kBAAkB;EAClB,kBAAkB;EAClB,0BAA0B;EAC1B,eAAe;AACjB;;AAEA;EACE,kCAAkC;AACpC;;AAEA;EACE,UAAU;EACV,YAAY;EACZ,4BAA4B;AAC9B;;AAEA;EACE,cAAc;EACd,eAAe;EACf,eAAe;EACf,iBAAiB;AACnB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,eAAe;EACf,kBAAkB;EAClB,mBAAmB;EACnB,mBAAmB;AACrB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,YAAY;EACZ,eAAe;EACf,kBAAkB;AACpB;;AAEA;;EAEE,mBAAmB;EACnB,cAAc;EACd,mBAAmB;EACnB,aAAa;EACb,eAAe;EACf,kBAAkB;EAClB,yBAAyB;EACzB,aAAa;AACf;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,uBAAuB;EACvB,qBAAqB;AACvB;;AAEA;EACE,WAAW;EACX,cAAc;AAChB;;AAEA;EACE,SAAS;EACT,sBAAsB;EACtB,gBAAgB;EAChB,uBAAuB;EACvB,yBAAyB;EACzB,kBAAkB;EAClB,qBAAqB;EACrB,aAAa;EACb,eAAe;EACf,YAAY;EACZ,gBAAgB;EAChB,8BAA8B;EAC9B;;yCAEuC;EACvC;6DAC2D;EAC3D,2CAA2C;EAC3C,4BAA4B;AAC9B;;AAEA;EACE,WAAW;AACb;;AAEA;EACE,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,qBAAqB;EACrB,2BAA2B;EAC3B,gBAAgB;EAChB,YAAY;EACZ,kBAAkB;EAClB,sBAAsB;EACtB,qBAAqB;EACrB,eAAe;EACf,gBAAgB;EAChB,cAAc;EACd,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;AACrB;;AAEA;EACE,mBAAmB;AACrB;;AAEA;EACE,yBAAyB;EACzB,eAAe;AACjB;;AAEA;EACE,mBAAmB;EACnB,mBAAmB;AACrB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,kBAAkB;AACpB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,mBAAmB;EACnB,kBAAkB;EAClB,kBAAkB;AACpB;;AAEA;EACE,eAAe;EACf,oBAAoB;EACpB,mBAAmB;AACrB;;AAEA;EACE,eAAe;EACf,mBAAmB;AACrB;;AAEA;EACE,eAAe;EACf,WAAW;EACX,0BAA0B;AAC5B;;AAEA;EACE,eAAe;EACf,0BAA0B;AAC5B;;AAEA,mBAAmB;;AAEnB;EACE,aAAa;EACb,gBAAgB;EAChB,YAAY;EACZ,mBAAmB;EACnB,gCAAgC;AAClC;;AAEA;EACE,OAAO;EACP,aAAa;EACb,gBAAgB;EAChB,YAAY;EACZ,mBAAmB;EACnB,+CAA+C;AACjD;;AAEA;EACE,aAAa;EACb,yBAAyB;EACzB,gBAAgB;EAChB,YAAY;EACZ,mBAAmB;EACnB,WAAW;AACb;;AAEA;EACE,aAAa;EACb,uBAAuB;AACzB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,cAAc;EACd,kBAAkB;EAClB,iBAAiB;AACnB;;AAEA;EACE,cAAc;EACd,kBAAkB;EAClB,gBAAgB;EAChB,eAAe;EACf,iBAAiB;AACnB;;AAEA;EACE,cAAc;EACd,eAAe;EACf,kBAAkB;EAClB,mBAAmB;EACnB,eAAe;AACjB;;AAEA;EACE,YAAY;EACZ,eAAe;EACf,kBAAkB;EAClB,mBAAmB;EACnB,eAAe;EACf,mBAAmB;EACnB,kBAAkB;EAClB,oBAAoB;AACtB;;AAEA;EACE,kBAAkB;EAClB,YAAY;EACZ,aAAa;EACb,sBAAsB;AACxB;;AAEA;EACE,aAAa;EACb,sBAAsB;AACxB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,mBAAmB;AACrB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,kBAAkB;EAClB,sBAAsB;EACtB,gBAAgB;AAClB;;AAEA;;;;EAIE,mBAAmB;EACnB,mBAAmB;EACnB,iBAAiB;AACnB;;AAEA;EACE,mBAAmB;EACnB,gBAAgB;EAChB,kBAAkB;EAClB,kBAAkB;AACpB;;AAEA;;EAEE,kBAAkB;AACpB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,YAAY;AACd;;AAEA;EACE,eAAe;EACf,oBAAoB;EACpB,kBAAkB;EAClB,sBAAsB;EACtB,cAAc;EACd,qBAAqB;EACrB,gBAAgB;AAClB;;AAEA;EACE,eAAe;EACf,iBAAiB;EACjB,kBAAkB;EAClB,gBAAgB;AAClB;;AAEA;AACA;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,YAAY;EACZ,kBAAkB;EAClB,mBAAmB;AACrB;;AAEA;EACE,mBAAmB;EACnB,kBAAkB;EAClB,kBAAkB;EAClB,wBAAwB;AAC1B;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,YAAY;AACd;;AAEA;EACE,eAAe;EACf,oBAAoB;EACpB,kBAAkB;AACpB;;AAEA;EACE,eAAe;AACjB;;AAEA;EACE,gBAAgB;EAChB,qBAAqB;EACrB,sBAAsB;EACtB,yDAAyD;EACzD,iDAAiD;EACjD,gBAAgB,EAAE,0CAA0C;EAC5D,QAAQ;AACV;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,eAAe;EACf,gBAAgB;EAChB,2EAA2E;EAC3E,uBAAuB;EACvB,WAAW;EACX,SAAS;EACT,eAAe;EACf,eAAe;EACf,gBAAgB;AAClB;;AAEA;EACE,cAAc;EACd,4BAA4B;AAC9B;;AAEA;EACE,YAAY;AACd;;AAEA;EACE;IACE,aAAa;EACf;AACF;;AAEA;EACE;IACE,aAAa;EACf;AACF;;AAEA;EACE,WAAW;EACX,aAAa;EACb,8BAA8B;AAChC;;AAEA;EACE,wBAAwB;EACxB,eAAe;AACjB;;AAEA;EACE,6BAA6B;EAC7B,mBAAmB;AACrB;;AAEA;EACE,kBAAkB;EAClB,mBAAmB;AACrB;;AAEA;EACE,kBAAkB;EAClB,mBAAmB;EACnB,eAAe;EACf,iBAAiB;EACjB,cAAc;EACd,qBAAqB;EACrB,sBAAsB;AACxB;;AAEA;EACE,eAAe;EACf,oBAAoB;EACpB,kBAAkB;AACpB;;AAEA;EACE,iBAAiB;EACjB,kBAAkB;EAClB,kBAAkB;EAClB,mBAAmB;EACnB,aAAa;EACb,aAAa;AACf;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,eAAe;EACf,gBAAgB;EAChB,cAAc;EACd,iBAAiB;AACnB;;AAEA;EACE,eAAe;EACf,oBAAoB;EACpB,kBAAkB;EAClB,cAAc;AAChB;;AAEA;EACE,aAAa;EACb,iBAAiB;EACjB,eAAe;AACjB;;AAEA;EACE,aAAa;EACb,YAAY;EACZ,mBAAmB;EACnB,uBAAuB;EACvB,mBAAmB;EACnB,kBAAkB;EAClB,eAAe;EACf,oBAAoB;EACpB,kBAAkB;EAClB,YAAY;EACZ,iBAAiB;EACjB,YAAY;EACZ,eAAe;AACjB;;AAEA;;EAEE,WAAW;EACX,YAAY;EACZ,iBAAiB;AACnB;;AAEA;;EAEE,qBAAqB;EACrB,gBAAgB;EAChB,mBAAmB;AACrB;;AAEA;EACE,cAAc;EACd,0BAA0B;AAC5B;;AAEA;;EAEE,cAAc;EACd,iBAAiB;EACjB,eAAe;AACjB;;AAEA;EACE,eAAe;EACf,cAAc;EACd,iBAAiB;AACnB;;AAEA;EACE,eAAe;EACf,cAAc;EACd,iBAAiB;EACjB,eAAe;AACjB;;AAEA;EACE,WAAW;EACX,iBAAiB;AACnB;;AAEA;;EAEE,mBAAmB;EACnB,YAAY;EACZ,eAAe;EACf,kBAAkB;EAClB,mBAAmB;AACrB;;AAEA;;EAEE,mBAAmB;EACnB,cAAc;AAChB;;AAEA;EACE,aAAa;EACb,YAAY;EACZ,kBAAkB;EAClB,gBAAgB;EAChB,mBAAmB;EACnB,mBAAmB;AACrB;;AAEA;EACE,aAAa;EACb,gBAAgB;EAChB,WAAW;EACX,gBAAgB;EAChB,mBAAmB;EACnB,yBAAyB;EACzB,uCAAuC;EACvC,kBAAkB;EAClB,yBAAyB;EACzB,mBAAmB;EACnB,iBAAiB;AACnB;;AAEA;EACE,YAAY;EACZ,YAAY;EACZ,OAAO;EACP,+BAA+B;EAC/B,kBAAkB;EAClB,eAAe;EACf,iBAAiB;EACjB,gBAAgB;EAChB,iBAAiB;EACjB,kBAAkB;AACpB;;AAEA;EACE,mBAAmB;AACrB;;AAEA;EACE,mBAAmB;EACnB,UAAU;AACZ;AACA;EACE,+BAA+B;AACjC;;AAEA;EACE,YAAY;EACZ,aAAa;AACf;;AAEA;EACE,YAAY;EACZ,mBAAmB;EACnB,YAAY;EACZ,cAAc;EACd,eAAe;EACf,aAAa;EACb,QAAQ;EACR,eAAe;AACjB;AACA;EACE,uBAAuB;AACzB;AACA;EACE,WAAW;EACX,mBAAmB;AACrB;;AAEA;EACE,YAAY;EACZ,mBAAmB;EACnB,YAAY;EACZ,kBAAkB;EAClB,YAAY;EACZ,eAAe;EACf,cAAc;AAChB;AACA;EACE,mBAAmB;EACnB,cAAc;AAChB;;AAEA;EACE,qBAAqB;EACrB,cAAc;EACd,mBAAmB;AACrB;;AAEA;EACE,WAAW;EACX,iBAAiB;EACjB,kBAAkB;AACpB;;AAEA;EACE,aAAa;EACb,kBAAkB;EAClB,mBAAmB;EACnB,gBAAgB;EAChB,mBAAmB;AACrB;;AAEA;EACE,6BAA6B;EAC7B,mBAAmB;EACnB,oBAAoB;EACpB,UAAU;AACZ;;AAEA;EACE,wBAAwB;EACxB,aAAa;EACb,gBAAgB;EAChB,cAAc;EACd,eAAe;AACjB;;AAEA;EACE,yBAAyB;EACzB,mBAAmB;AACrB;;AAEA;EACE,WAAW;EACX,iBAAiB;EACjB,mBAAmB;AACrB;;AAEA;EACE,eAAe;AACjB;;AAEA;EACE,aAAa;EACb,sBAAsB;AACxB;;AAEA;EACE,aAAa;EACb,WAAW;EACX,kBAAkB;EAClB,kBAAkB;EAClB,mBAAmB;AACrB;;AAEA;EACE,WAAW;EACX,sEAAsE;EACtE,gCAAgC;AAClC;;AAEA;EACE,aAAa;EACb,eAAe;EACf,iBAAiB;EACjB,2BAA2B;AAC7B;;AAEA;EACE,aAAa;EACb,iBAAiB;EACjB,iBAAiB;EACjB,kBAAkB;AACpB;;AAEA;EACE,eAAe;AACjB;;AAEA;;;;EAIE,cAAc;EACd,eAAe;AACjB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,qBAAqB;EACrB,gBAAgB;AAClB;;AAEA;;EAEE,WAAW;EACX,eAAe;EACf,cAAc;AAChB;;AAEA;EACE,gBAAgB;AAClB;;AAEA;;;EAGE,cAAc;AAChB;;AAEA;EACE,iBAAiB;AACnB;;AAEA;EACE,aAAa;EACb,iBAAiB;AACnB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,iBAAiB;EACjB,cAAc;AAChB;;AAEA;EACE,4CAA4C;EAC5C,wBAAwB;EACxB,4BAA4B;EAC5B,sCAAsC;AACxC;;AAEA;EACE,cAAc;AAChB;;AAEA;EACE,cAAc;AAChB;;AAEA;EACE,0CAA0C;EAC1C,sBAAsB;EACtB,4BAA4B;EAC5B,sCAAsC;AACxC;;AAEA;EACE;;IAEE,mBAAmB;EACrB;EACA;IACE,sBAAsB;EACxB;AACF;;AAEA;;EAEE,kBAAkB;EAClB,UAAU;EACV,WAAW;EACX,mBAAmB;AACrB;;AAEA;EACE,kBAAkB;AACpB;;AAEA;EACE,mBAAmB;EACnB,mBAAmB;EACnB,WAAW;EACX,wBAAwB;EACxB,WAAW;AACb;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,yBAAyB;EACzB,sBAAsB;EACtB,kBAAkB;AACpB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,mBAAmB;AACrB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,kBAAkB;AACpB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,kBAAkB;EAClB,mBAAmB;EACnB,yBAAyB;AAC3B;;AAEA;EACE,eAAe;AACjB;;AAEA;EACE,gBAAgB;EAChB,YAAY;EACZ,mBAAmB;EACnB,aAAa;EACb,mBAAmB;EACnB,yBAAyB;EACzB,kBAAkB;EAClB,yBAAyB;EACzB,kBAAkB;AACpB;;AAEA;EACE,mBAAmB;AACrB;;AAEA;AACA;;AAEA;EACE,aAAa;EACb,yBAAyB;AAC3B;;AAEA;EACE,YAAY;EACZ,eAAe;EACf,mBAAmB;EACnB,kBAAkB;EAClB,kBAAkB;EAClB,mBAAmB;EACnB,eAAe;EACf,YAAY;EACZ,YAAY;EACZ,eAAe;AACjB;;AAEA;EACE,mBAAmB;EACnB,cAAc;AAChB;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,gBAAgB;EAChB,mBAAmB;EACnB,kBAAkB;AACpB;;AAEA;EACE,+CAA+C;EAC/C,aAAa;EACb,8BAA8B;EAC9B,kBAAkB;AACpB;;AAEA;EACE,eAAe;EACf,iBAAiB;EACjB,mBAAmB;AACrB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,oBAAoB;EACpB,SAAS;EACT,eAAe;EACf,cAAc;AAChB;;AAEA;EACE,cAAc;AAChB;;AAEA;EACE,iBAAiB;AACnB;;AAEA;EACE,eAAe;EACf,oBAAoB;EACpB,cAAc;EACd,mBAAmB;EACnB,aAAa;EACb,sBAAsB;AACxB;;AAEA;AACA;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,mBAAmB;AACrB;;AAEA;EACE,eAAe;EACf,YAAY;AACd;;AAEA;;EAEE,WAAW;EACX,iBAAiB;EACjB,qBAAqB;AACvB;;AAEA;;EAEE,mBAAmB;EACnB,mBAAmB;EACnB,kBAAkB;EAClB,YAAY;EACZ,YAAY;EACZ,eAAe;EACf,aAAa;EACb,eAAe;EACf,kBAAkB;EAClB,uBAAuB;EACvB,kBAAkB;EAClB,gBAAgB;EAChB,iBAAiB;EACjB,kBAAkB;EAClB,YAAY;AACd;;AAEA;;EAEE,mBAAmB;EACnB,cAAc;AAChB;;AAEA;EACE,eAAe;AACjB;;AAEA;EACE,WAAW;EACX,mBAAmB;EACnB,kBAAkB;EAClB,YAAY;EACZ,eAAe;EACf,aAAa;EACb,eAAe;EACf,kBAAkB;EAClB,uBAAuB;EACvB,YAAY;AACd;;AAEA;EACE,cAAc;EACd,0BAA0B;AAC5B;;AAEA;;;EAGE,aAAa;EACb,YAAY;EACZ,mBAAmB;EACnB,cAAc;EACd,uBAAuB;EACvB,mBAAmB;EACnB,kBAAkB;EAClB,eAAe;EACf,gBAAgB;EAChB,kBAAkB;EAClB,YAAY;EACZ,eAAe;EACf,yBAAyB;EACzB,8BAA8B;EAC9B,iCAAiC;AACnC;;AAEA;;;EAGE,mBAAmB;EACnB,WAAW;EACX,mBAAmB;AACrB;;AAEA;EACE,iBAAiB;AACnB;AACA;;;EAGE,kCAAkC;EAClC,YAAY;AACd;;AAEA;;;EAGE,mBAAmB;AACrB;;AAEA;EACE,YAAY;AACd;;AAEA;EACE,aAAa;EACb,8BAA8B;EAC9B,mBAAmB;EACnB,kBAAkB;EAClB,mBAAmB;EACnB,gBAAgB;EAChB,kBAAkB;EAClB,SAAS;AACX;;AAEA;EACE,0BAA0B;AAC5B;;AAEA;EACE,0BAA0B;EAC1B,aAAa;EACb,8BAA8B;AAChC;;AAEA;EACE,eAAe;EACf,oBAAoB;EACpB,mBAAmB;EACnB,gBAAgB;EAChB,gCAAgC;AAClC;;AAEA;EACE,eAAe;EACf,mBAAmB;AACrB;;AAEA;EACE,cAAc;EACd,0BAA0B;AAC5B;;AAEA;;;EAGE,gBAAgB;EAChB,kBAAkB;EAClB,aAAa;EACb,mBAAmB;EACnB,YAAY;EACZ,YAAY;EACZ,eAAe;EACf,eAAe;AACjB;;AAEA;EACE,iBAAiB;AACnB;;;AAGA;EACE,mBAAmB;EACnB,YAAY;AACd;;AAEA;EACE,kBAAkB;EAClB,aAAa;EACb,mBAAmB;EACnB,YAAY;EACZ,YAAY;EACZ,eAAe;AACjB;;AAEA;EACE,kBAAkB;EAClB,oBAAoB;EACpB,sCAAsC;EACtC,aAAa;EACb,eAAe;AACjB;;AAEA;EACE,cAAc;EACd,eAAe;EACf,mBAAmB;AACrB;;AAEA;EACE,YAAY;EACZ,gBAAgB;EAChB,aAAa;EACb,mBAAmB;EACnB,gCAAgC;EAChC,yCAAyC;AAC3C;;AAEA;EACE,mBAAmB;EACnB,gBAAgB;AAClB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,iBAAiB;EACjB,eAAe;EACf,cAAc;EACd,eAAe;EACf,iBAAiB;EACjB,yBAAyB;AAC3B;;AAEA;EACE,WAAW;EACX,eAAe;EACf,iBAAiB;AACnB;;AAEA;EACE,aAAa;EACb,OAAO;EACP,uBAAuB;EACvB,mBAAmB;AACrB;;AAEA;EACE,eAAe;AACjB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,eAAe;EACf,kBAAkB;EAClB,iBAAiB;EACjB,kBAAkB;EAClB,mBAAmB;EACnB,YAAY;EACZ,eAAe;EACf,iBAAiB;EACjB,yBAAyB;AAC3B;;AAEA;EACE,mBAAmB;EACnB,cAAc;AAChB;;AAEA;EACE,qBAAqB;EACrB,cAAc;EACd,eAAe;AACjB;;AAEA;EACE,WAAW;EACX,kBAAkB;AACpB;;AAEA;EACE,eAAe;EACf,cAAc;AAChB;;AAEA;EACE,cAAc;EACd,0BAA0B;AAC5B;;AAEA;EACE,yBAAyB;EACzB,YAAY;EACZ,eAAe;EACf,aAAa;EACb,mBAAmB;EACnB,gCAAgC;EAChC,WAAW;AACb;;AAEA;EACE,WAAW;EACX,gBAAgB;EAChB,iBAAiB;EACjB,kBAAkB;EAClB,cAAc;EACd,eAAe;AACjB;;AAEA;EACE,WAAW;EACX,aAAa;EACb,kBAAkB;AACpB;;AAEA;EACE,eAAe;EACf,gBAAgB;EAChB,uBAAuB;EACvB,mBAAmB;EACnB,YAAY;AACd;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,8BAA8B;EAC9B,yBAAyB;EACzB,kBAAkB;EAClB,aAAa;EACb,kBAAkB;EAClB,eAAe;AACjB;AACA;EACE,kCAAkC;AACpC;;AAEA;EACE,WAAW;EACX,kBAAkB;AACpB;;AAEA;EACE,kBAAkB;EAClB,SAAS;EACT,gBAAgB;EAChB,oCAAoC;EACpC,aAAa;AACf;;AAEA;EACE,kBAAkB;EAClB,0BAA0B;EAC1B,iBAAiB;EACjB,UAAU;EACV,4BAA4B;AAC9B;;AAEA;EACE,wCAAwC;AAC1C;;AAEA;EACE,kBAAkB;EAClB,mBAAmB;EACnB,eAAe;EACf,YAAY;EACZ,WAAW;AACb;AACA;EACE,gBAAgB;EAChB,mBAAmB;EACnB,iBAAiB;EACjB,eAAe;EACf,2BAA2B;AAC7B;AACA;EACE,aAAa;EACb,sBAAsB;AACxB;AACA;EACE,YAAY;EACZ,kBAAkB;EAClB,aAAa;EACb,mBAAmB;EACnB,kBAAkB;EAClB,mBAAmB;EACnB,kBAAkB;AACpB;AACA;EACE,qBAAqB;AACvB;;AAEA;EACE,mBAAmB;EACnB,eAAe;AACjB;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,eAAe;EACf,eAAe;EACf,iBAAiB;EACjB,cAAc;AAChB;;AAEA;EACE,gBAAgB;EAChB,eAAe;EACf,mBAAmB;EACnB,uBAAuB;AACzB;;AAEA;EACE,YAAY;EACZ,cAAc;EACd,eAAe;EACf,aAAa;EACb,iBAAiB;AACnB;;AAEA;EACE,WAAW;AACb;;AAEA;EACE,cAAc;AAChB;;AAEA;EACE,0BAA0B;EAC1B,aAAa;EACb,sBAAsB;EACtB,mBAAmB;EACnB,uBAAuB;EACvB,eAAe;EACf,2BAA2B;AAC7B;;AAEA;EACE,eAAe;EACf,YAAY;EACZ,WAAW;EACX,YAAY;AACd;;AAEA;EACE,kBAAkB;EAClB,0CAA0C;EAC1C,uCAAuC;EACvC,kBAAkB;EAClB,iBAAiB;EACjB,UAAU;AACZ;;AAEA;EACE,kBAAkB;EAClB,0CAA0C;EAC1C,uCAAuC;EACvC,kBAAkB;EAClB,iBAAiB;EACjB,UAAU;AACZ;;AAEA;EACE,eAAe;EACf,YAAY;EACZ,aAAa;EACb,sBAAsB;AACxB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,8BAA8B;EAC9B,eAAe;EACf,iBAAiB;EACjB,iBAAiB;EACjB,oBAAoB;EACpB,cAAc;AAChB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,cAAc;EACd,kBAAkB;EAClB,gBAAgB;EAChB,eAAe;AACjB;;AAEA;EACE,mBAAmB;EACnB,kBAAkB;EAClB,kBAAkB;EAClB,wBAAwB;AAC1B;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,YAAY;AACd;;AAEA;EACE,WAAW;EACX,2BAA2B;EAC3B,eAAe;AACjB;;AAEA;EACE,2BAA2B;AAC7B;;AAEA;EACE,aAAa;EACb,sBAAsB;EACtB,QAAQ;EACR,oBAAoB;AACtB;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,8BAA8B;EAC9B,iBAAiB;EACjB,yBAAyB;EACzB,kBAAkB;EAClB,kBAAkB;EAClB,0BAA0B;EAC1B,eAAe;AACjB;;AAEA;EACE,kCAAkC;AACpC;;AAEA;EACE,UAAU;EACV,YAAY;EACZ,4BAA4B;AAC9B;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,eAAe;EACf,gBAAgB;EAChB,sBAAsB;AACxB","sourcesContent":["/*\n    See the JupyterLab Developer Guide for useful CSS Patterns:\n\n    https://jupyterlab.readthedocs.io/en/stable/developer/css.html\n*/\n\n.as-widget-container {\n  min-width: 480px !important;\n  background: #f5f5f5;\n  height: 100%;\n}\n\n.as-widget-content {\n  height: 100%;\n  background: #f5f5f5;\n  color: #000;\n}\n\n.as-container {\n  background: white;\n  border-radius: 4px;\n  color: #212121;\n  display: flex;\n  flex-direction: column;\n  font-family: SF Pro, Tahoma, sans-serif;\n  height: 100%;\n  overflow: auto;\n  width: 100%;\n}\n\n.as-header-container {\n  display: flex;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  justify-content: flex-end;\n}\n\n.as-header-settings-icon {\n  height: 15px;\n  width: 15px;\n  margin-right: 16px;\n  color: #6a718a;\n  cursor: pointer;\n}\n\n.as-header-settings-text {\n  color: #3874cb;\n  font-style: normal;\n  font-weight: 510;\n  font-size: 13px;\n  line-height: 16px;\n  padding-right: 20px;\n}\n\n.as-login-container {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  margin: 50px 50px;\n  background: white;\n  color: #2C303A;\n  height: 100%;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-login-container a {\n  color: #6C5AF6;\n  text-decoration: underline;\n  cursor: pointer;\n}\n\n.as-login-header {\n  display: flex;\n  margin-bottom: 40px;\n  color: #2C303A;\n}\n\n.as-login-body,\n.as-login-footer {\n  margin-left: 15px;\n}\n\n.as-login-body {\n  flex-grow: 1;\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 24px;\n}\n\n.as-login-body ul {\n  margin: 20px 0;\n  padding: 0;\n  list-style: none;\n}\n\n.as-login-body ul li {\n  display: flex;\n  margin-bottom: 15px;\n  align-items: center;\n}\n\n.as-login-body ul li * {\n  fill: #0CCA4A;\n}\n\n.as-login-body ul li.coming-soon {\n  color: #6C5AF6;\n  margin-top: 35px;\n}\n\n.as-login-body ul li.disabled,\n.as-login-body ul li.disabled * {\n  color: #ABB1BF;\n  fill: #ABB1BF;\n}\n\n.as-create-account-button {\n  margin-bottom: 20px;\n  margin-top: 20px;\n  border-radius: 4px;\n  padding: 10px 16px;\n  background: #0CCA4A;\n  border: none;\n  color: #06262D;\n  cursor: pointer;\n  font-size: 16px;\n  font-weight: 700;\n  line-height: 24px;\n}\n\n.as-create-account-button:hover {\n  background: #4FAB4F;\n}\n\n.as-login-sign-in-text {\n  font-size: 14px;\n  font-weight: 400;\n  line-height: 17px;\n}\n\n.as-login-footer {\n  font-size: 16px;\n  font-weight: 500;\n  line-height: 20px;\n  display: flex;\n  margin-bottom: 60px;\n}\n\n.as-login-footer svg,\n.as-login-body svg {\n  width: 17px;\n  height: 17px;\n  margin-right: 10px;\n}\n\n.as-login-footer svg {\n  width: 20px;\n  height: 20px;\n}\n.as-login-icon {\n  min-width: 30px;\n  max-width: 30px;\n  color: #31a824;\n}\n\n.as-title-text {\n  font-size: 24px;\n  font-weight: 700;\n  margin-left: 10px;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-subtitle-text {\n  font-size: 16px;\n  font-weight: 400;\n  line-height: 24px;\n}\n\n.as-sub-title-container {\n  display: flex;\n  gap: 5px;\n  width: 80%;\n  color: #2c303a;\n  background: #43b0491f;\n  padding: 10px 12px;\n  border-radius: 8px;\n  margin-top: 25px;\n}\n\n.as-home-screen-header {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  margin-bottom: 10px;\n}\n\n.as-home-screen-container {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  padding-left: 20px;\n  padding-right: 20px;\n  background: white;\n}\n\n.as-home-screen-icon {\n  width: 80px;\n  color: #31a824;\n}\n\n.as-sub-title-text {\n  font-size: 14px;\n  line-height: 20px;\n  font-weight: 400;\n  text-align: center;\n}\n\n.as-home-screen-body {\n  font-size: 13px;\n}\n\n.as-home-screen-section {\n  display: flex;\n  align-items: center;\n  font-size: 13px;\n  font-weight: 590;\n  letter-spacing: 0.02em;\n  margin-top: 20px;\n  margin-bottom: 10px;\n}\n\n.as-home-screen-df-icon-container {\n  width: 26px;\n  height: 26px;\n  background: #e9e6fe;\n  border-radius: 100px;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  margin-right: 10px;\n}\n\n.as-home-screen-df-icon {\n  width: 12px;\n  height: 12px;\n  color: #6c5af6;\n}\n\n.as-home-screen-code-icon-container {\n  width: 26px;\n  height: 26px;\n  background: rgba(0, 178, 255, 0.1);\n  border-radius: 100px;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  margin-right: 10px;\n}\n\n.as-home-screen-code-icon {\n  width: 13px;\n  color: #00b2ff;\n}\n\n.as-home-screen-chat-starter {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  border: 1px solid #e6e6e6;\n  margin-bottom: 3px;\n  border-radius: 8px;\n  padding: 9px 12px 9px 12px;\n  cursor: pointer;\n}\n\n.as-home-screen-chat-starter:hover {\n  background: rgba(33, 33, 33, 0.05);\n}\n\n.as-home-screen-starter-icon {\n  width: 8px;\n  height: 12px;\n  color: rgba(33, 33, 33, 0.5);\n}\n\n.as-version-text {\n  color: #bdbdbd;\n  font-size: 11px;\n  margin-top: 4px;\n  margin-left: 10px;\n}\n\n.as-graph-selector-container {\n  display: flex;\n  flex-direction: column;\n  font-size: 13px;\n  padding-left: 20px;\n  padding-right: 20px;\n  margin-bottom: 20px;\n}\n\n.as-graph-selector-message-container {\n  display: flex;\n  align-items: center;\n  height: 50px;\n  margin-top: 5px;\n  margin-bottom: 8px;\n}\n\n.as-code-share-warning-message,\n.as-dataframe-select-warning-message {\n  margin-bottom: 20px;\n  color: #757575;\n  background: #fcfccc;\n  padding: 10px;\n  font-size: 11px;\n  border-radius: 4px;\n  border: 1px solid #ebebbe;\n  display: flex;\n}\n\n.as-warning-icon-wrapper {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  padding: 0 12px 0 3px;\n}\n\n.as-warning-icon {\n  width: 23px;\n  color: #ffba0a;\n}\n\n.as-dataframe-select {\n  margin: 0;\n  box-sizing: border-box;\n  appearance: none;\n  background-color: white;\n  border: 1px solid #e0e0e0;\n  border-radius: 4px;\n  display: inline-block;\n  font: inherit;\n  font-size: 13px;\n  height: 40px;\n  line-height: 1em;\n  padding: 0.5em 3.5em 0.5em 1em;\n  background-image: linear-gradient(45deg, transparent 50%, gray 50%),\n    linear-gradient(135deg, gray 50%, transparent 50%),\n    linear-gradient(to right, #ccc, #ccc);\n  background-position: calc(100% - 20px) calc(1em + 4px),\n    calc(100% - 15px) calc(1em + 4px), calc(100% - 2.5em) 9px;\n  background-size: 5px 5px, 5px 5px, 1px 20px;\n  background-repeat: no-repeat;\n}\n\nselect:invalid {\n  color: gray;\n}\n\n.as-get-code-button {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  padding: 0.35em 1.2em;\n  border: 0.1em solid #ffffff;\n  margin-top: 16px;\n  height: 40px;\n  border-radius: 4px;\n  box-sizing: border-box;\n  text-decoration: none;\n  font-size: 13px;\n  font-weight: 300;\n  color: #06262d;\n  text-align: center;\n  transition: all 0.5s;\n  background: #0cca4a;\n}\n\n.as-get-code-button.disabled {\n  background: #bdbdbd;\n}\n\n.as-get-code-button:hover {\n  background-color: #4fab4f;\n  cursor: pointer;\n}\n\n.as-get-code-button:hover.disabled {\n  cursor: not-allowed;\n  background: #bdbdbd;\n}\n\n.as-get-code-button-icon {\n  width: 16px;\n  height: 16px;\n  margin-right: 10px;\n}\n\n.as-no-dataframe-container {\n  display: flex;\n  flex-direction: column;\n  background: #f7f7f7;\n  border-radius: 4px;\n  padding: 20px 10px;\n}\n\n.as-no-dataframe-heading {\n  font-size: 14px;\n  font-weight: lighter;\n  margin-bottom: 20px;\n}\n\n.as-no-dataframe-text {\n  font-size: 12px;\n  margin-bottom: 10px;\n}\n\n.as-no-dataframe-link {\n  display: inline;\n  color: blue;\n  text-decoration: underline;\n}\n\n.as-no-dataframe-link:hover {\n  color: darkblue;\n  text-decoration: underline;\n}\n\n/*Main Chat Screen*/\n\n.as-chat-header-container {\n  display: flex;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-chat-header-title-container {\n  flex: 1;\n  display: flex;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  border-bottom: 1px solid rgba(85, 85, 85, 0.05);\n}\n\n.as-chat-header-settings-container {\n  display: flex;\n  justify-content: flex-end;\n  min-height: 50px;\n  height: 50px;\n  align-items: center;\n  width: 50px;\n}\n\n.as-chat-header-text-icon {\n  display: flex;\n  justify-content: center;\n}\n\n.as-chat-header-main-icon {\n  width: 20px;\n  height: 15px;\n  color: #31a824;\n  padding-left: 15px;\n  margin-right: 7px;\n}\n\n.as-chat-header-main-text {\n  color: #2c303a;\n  font-style: normal;\n  font-weight: 700;\n  font-size: 16px;\n  line-height: 24px;\n}\n\n.as-chat-header-version-text {\n  color: #bdbdbd;\n  font-size: 11px;\n  padding-left: 10px;\n  padding-right: 10px;\n  margin-top: 2px;\n}\n\n.as-chat-header-pro-tier-text {\n  color: white;\n  font-size: 11px;\n  padding-left: 10px;\n  padding-right: 10px;\n  margin-top: 2px;\n  background: #31a824;\n  border-radius: 4px;\n  padding: 3px 6px 1px;\n}\n\n.as-chat-main-section {\n  overflow-y: scroll;\n  height: 100%;\n  display: flex;\n  flex-direction: column;\n}\n\n.as-chat-message-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.as-user-chat-message-buttons-container {\n  display: flex;\n  flex-direction: column;\n  background: #e9e6fe;\n}\n\n.as-user-chat-message-container {\n  display: flex;\n  flex-direction: column;\n  align-items: start;\n  padding: 10px 20px 5px;\n  min-height: 50px;\n}\n\n.as-user-chat-message-buttons-container:first-child\n  .as-user-chat-message-container,\n.as-user-chat-message-buttons-container:nth-child(2)\n  .as-user-chat-message-container {\n  flex-direction: row;\n  align-items: center;\n  padding: 5px 20px;\n}\n\n.as-user-chat-message-icon-container {\n  background: #6c5af6;\n  padding: 6px 7px;\n  margin-right: 10px;\n  border-radius: 4px;\n}\n\n.as-user-chat-message-buttons-container:not(:first-child):not(:nth-child(2))\n  .as-user-chat-message-icon-container {\n  margin-bottom: 5px;\n}\n\n.as-user-chat-message-icon {\n  width: 14px;\n  height: 16px;\n  color: white;\n}\n\n.as-user-chat-message-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n  word-break: break-word;\n  padding: 6px 0;\n  white-space: pre-wrap;\n  margin-left: 1px;\n}\n\n.as-user-chat-message-text-bold {\n  font-size: 13px;\n  font-weight: bold;\n  font-style: normal;\n  margin-left: 5px;\n}\n\n.as-code-container {\n}\n\n.as-code-message-container {\n  display: flex;\n  align-items: center;\n  height: 50px;\n  padding-left: 20px;\n  padding-right: 20px;\n}\n\n.as-code-message-icon-container {\n  background: #4fab4f;\n  border-radius: 4px;\n  margin-right: 10px;\n  padding: 8px 4px 5px 4px;\n}\n\n.as-code-message-icon {\n  width: 20px;\n  height: 16px;\n  color: white;\n}\n\n.as-code-message-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n}\n\n.as-code-loading {\n  font-size: 13px;\n}\n\n.as-code-loading:after {\n  overflow: hidden;\n  display: inline-block;\n  vertical-align: bottom;\n  -webkit-animation: ellipsis steps(4, end) 1200ms infinite;\n  animation: ellipsis steps(4, end) 1200ms infinite;\n  content: \"\\2026\"; /* ascii code for the ellipsis character */\n  width: 0;\n}\n\n.as-export-chat-container {\n  display: flex;\n  align-items: center;\n  padding: 0 20px;\n  min-height: 50px;\n  background: linear-gradient(white, white, white, #fdfdfd, #fafafa, #f8f8f8);\n  justify-content: center;\n  color: #ccc;\n  gap: 10px;\n  font-size: 12px;\n  cursor: pointer;\n  margin-top: auto;\n}\n\n.as-export-chat-container:hover {\n  color: #6c5af6;\n  text-shadow: 1px 1px 0 white;\n}\n\n.as-export-chat-container svg {\n  height: 12px;\n}\n\n@keyframes ellipsis {\n  to {\n    width: 1.25em;\n  }\n}\n\n@-webkit-keyframes ellipsis {\n  to {\n    width: 1.25em;\n  }\n}\n\n.as-code-generate-container {\n  width: 100%;\n  display: flex;\n  justify-content: space-between;\n}\n\n.as-code-generate-refresh {\n  color: rgb(56, 116, 203);\n  cursor: pointer;\n}\n\n.as-code-generate-refresh-disabled {\n  color: rgb(56, 116, 203, 0.5);\n  cursor: not-allowed;\n}\n\n.as-code-block {\n  padding-left: 20px;\n  padding-right: 20px;\n}\n\n.as-text-block {\n  padding-left: 21px;\n  padding-right: 20px;\n  font-size: 13px;\n  line-height: 20px;\n  color: #20262f;\n  white-space: pre-wrap;\n  word-break: break-word;\n}\n\n.as-code-error-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n}\n\n.as-code-error-panel {\n  margin-left: 20px;\n  margin-right: 20px;\n  border-radius: 4px;\n  background: #fef1f1;\n  display: flex;\n  padding: 16px;\n}\n\n.as-code-error-icon {\n  width: 16px;\n  height: 16px;\n  min-width: 16px;\n  min-height: 16px;\n  color: #f44336;\n  margin-right: 8px;\n}\n\n.as-code-error-panel-text {\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n  color: #d60000;\n}\n\n.as-code-error-footer {\n  display: flex;\n  margin-left: 20px;\n  margin-top: 8px;\n}\n\n.as-code-retry-button {\n  display: flex;\n  border: none;\n  background: #3d3d3d;\n  justify-content: center;\n  align-items: center;\n  border-radius: 4px;\n  font-size: 13px;\n  font-weight: lighter;\n  font-style: normal;\n  padding: 8px;\n  margin-right: 8px;\n  color: white;\n  cursor: pointer;\n}\n\n.as-code-retry-icon,\n.as-code-copy-icon {\n  width: 16px;\n  height: 16px;\n  margin-right: 8px;\n}\n\n.as-code-error-token-limit .as-code-error-panel,\n.as-code-error-upgrade .as-code-error-panel {\n  background: #43b0491f;\n  margin-top: 20px;\n  margin-bottom: 20px;\n}\n\n.as-code-error-token-limit .as-code-error-panel-text a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-code-error-token-limit .as-code-error-panel-text,\n.as-code-error-upgrade .as-code-error-panel-text {\n  color: #2c303a;\n  margin-left: 10px;\n  font-size: 13px;\n}\n\n.as-code-error-upgrade .as-code-error-icon {\n  min-width: 42px;\n  color: #31a824;\n  margin-right: 8px;\n}\n\n.as-code-error-token-limit .as-code-error-icon {\n  min-width: 42px;\n  color: #31a824;\n  margin-right: 4px;\n  margin-top: 2px;\n}\n\n.as-code-error-token-limit .as-code-error-token-limit-restart-button svg {\n  width: 12px;\n  margin-right: 4px;\n}\n\n.as-code-error-token-limit .as-code-retry-button,\n.as-code-error-upgrade .as-code-retry-button {\n  background: #4fab4f;\n  color: white;\n  font-size: 16px;\n  margin-right: 20px;\n  margin-bottom: 40px;\n}\n\n.as-code-error-token-limit .as-code-retry-button:hover,\n.as-code-error-upgrade .as-code-retry-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-instruction-container {\n  display: flex;\n  height: 50px;\n  padding-left: 20px;\n  padding-top: 8px;\n  padding-right: 20px;\n  margin-bottom: 10px;\n}\n\n.as-instruction-input-form {\n  display: flex;\n  align-items: end;\n  width: 100%;\n  min-height: 36px;\n  background: #ffffff;\n  border: 1px solid #e0e0e0;\n  box-shadow: 0 0 8px rgba(0, 0, 0, 0.07);\n  border-radius: 8px;\n  padding: 7px 6px 6px 16px;\n  margin-bottom: 10px;\n  max-height: 215px;\n}\n\n.as-instruction-input-textarea {\n  border: none;\n  resize: none;\n  flex: 1;\n  font-family: Tahoma, sans-serif;\n  background: canvas;\n  font-size: 12px;\n  line-height: 16px;\n  min-height: 16px;\n  max-height: 200px;\n  margin-bottom: 8px;\n}\n\n.as-instruction-input-textarea:disabled {\n  cursor: not-allowed;\n}\n\n.as-instruction-input-textarea::placeholder:disabled {\n  cursor: not-allowed;\n  color: red;\n}\n.as-instruction-input-textarea:disabled::placeholder {\n  color: rgba(211, 211, 211, 0.5);\n}\n\n.as-instruction-input-textarea:focus {\n  border: none;\n  outline: none;\n}\n\n.as-instruction-attach-context-button {\n  border: none;\n  background: inherit;\n  padding: 0px;\n  color: #6c5af6;\n  cursor: pointer;\n  display: flex;\n  gap: 6px;\n  font-size: 13px;\n}\n.as-instruction-attach-context-button:hover {\n  filter: brightness(1.2);\n}\n.as-instruction-attach-context-button:disabled {\n  color: #999;\n  cursor: not-allowed;\n}\n\n.as-instruction-submit-button {\n  border: none;\n  background: #4fab4f;\n  color: white;\n  border-radius: 4px;\n  height: 100%;\n  cursor: pointer;\n  padding: 0 8px;\n}\n.as-instruction-submit-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-instruction-submit-button:disabled {\n  background: #43b04933;\n  color: #31a824;\n  cursor: not-allowed;\n}\n\n.as-instruction-send-icon {\n  width: 14px;\n  padding-left: 6px;\n  padding-right: 6px;\n}\n\n.as-chat-footer {\n  display: flex;\n  padding-left: 20px;\n  padding-right: 20px;\n  padding-top: 2px;\n  align-items: center;\n}\n\n.as-chat-footer-container {\n  border-top: 1px solid #e0e0e0;\n  background: #f5f5f5;\n  padding-bottom: 16px;\n  z-index: 2;\n}\n\n.as-chat-reset-container {\n  transition: opacity 0.5s;\n  display: flex;\n  align-items: end;\n  color: #6c5af6;\n  cursor: pointer;\n}\n\n.as-chat-reset-container-disabled {\n  color: rgb(183, 192, 206);\n  cursor: not-allowed;\n}\n\n.as-chat-reset-icon {\n  width: 12px;\n  margin-right: 4px;\n  margin-bottom: -2px;\n}\n\n.as-chat-reset-text {\n  font-size: 11px;\n}\n\n.as-chat-token-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.as-chat-token-bar-container {\n  display: flex;\n  width: 72px;\n  margin-right: 16px;\n  margin-bottom: 6px;\n  background: #e1e1e1;\n}\n\n.as-chat-token-filled {\n  height: 7px;\n  background: linear-gradient(270deg, #ffb84f 0%, #76dd5c 100%), #80b241;\n  transition: width 1s ease-in-out;\n}\n\n.as-chat-token-text {\n  display: flex;\n  font-size: 11px;\n  margin-right: 4px;\n  color: rgb(33, 33, 33, 0.5);\n}\n\n.as-chat-token-count {\n  display: flex;\n  font-weight: bold;\n  padding-left: 5px;\n  padding-right: 5px;\n}\n\n.as-user-chat-message-buttons-container .as-message-buttons-container {\n  margin-top: 0px;\n}\n\n.as-user-chat-message-buttons-container\n  .as-message-buttons-container\n  *:not(.as-code-feedback-modal)\n  svg {\n  color: #ceced4;\n  cursor: pointer;\n}\n\n.as-message-buttons-container {\n  display: flex;\n  align-items: center;\n  padding: 0px 20px 5px;\n  margin-top: 15px;\n}\n\n.as-message-export-icon-container svg,\n.as-code-feedback-thumbs-icon svg {\n  width: 14px;\n  cursor: pointer;\n  color: #e0e0e0;\n}\n\n.as-code-feedback-thumbs-icon svg {\n  margin-left: 8px;\n}\n\ndiv\n  .as-message-buttons-container\n  *:not(.as-code-feedback-modal) svg:hover {\n  color: #9ca3af;\n}\n\n.as-message-button-trash-icon-container {\n  margin-left: auto;\n}\n\n.as-code-feedback-thumbs-icons {\n  display: flex;\n  margin-left: auto;\n}\n\n.as-code-feedback-thumbs-icon-completed {\n  width: 16px;\n  height: 16px;\n  margin-right: 8px;\n  color: #e0e0e0;\n}\n\n.as-code-feedback-thumbs-completed-beat {\n  animation: as-code-thumbs-beat 0.5s infinite;\n  animation-duration: 0.5s;\n  animation-iteration-count: 1;\n  animation-timing-function: ease-in-out;\n}\n\n.as-code-feedback-thumbs-up svg {\n  color: #14d662;\n}\n\n.as-code-feedback-thumbs-down svg {\n  color: #f29c9c;\n}\n\n.as-code-thumbs-initial-beat {\n  animation: as-code-thumbs-beat 1s infinite;\n  animation-duration: 1s;\n  animation-iteration-count: 2;\n  animation-timing-function: ease-in-out;\n}\n\n@keyframes as-code-thumbs-beat {\n  0%,\n  90% {\n    transform: scale(1);\n  }\n  45% {\n    transform: scale(1.25);\n  }\n}\n\n#as-arrow,\n#as-arrow::before {\n  position: absolute;\n  width: 8px;\n  height: 8px;\n  background: #caecca;\n}\n\n#as-arrow {\n  visibility: hidden;\n}\n\n#as-arrow::before {\n  visibility: visible;\n  background: #caecca;\n  content: \"\";\n  transform: rotate(45deg);\n  bottom: 4px;\n}\n\n.as-code-feedback-modal {\n  padding: 15px;\n  background: #caecca;\n  border: 1px solid #c4d4b8;\n  color: rgb(90, 86, 97);\n  border-radius: 4px;\n}\n\n.as-code-feedback-modal-header {\n  display: flex;\n  align-items: center;\n  margin-bottom: 15px;\n}\n\n.as-code-feedback-header-positive-icon {\n  width: 20px;\n  height: 20px;\n  margin-right: 10px;\n}\n\n.as-code-feedback-header-negative-icon {\n  width: 20px;\n  height: 20px;\n  margin-right: 10px;\n  margin-bottom: -6px;\n  transform: rotate(180deg);\n}\n\n.as-code-feedback-modal-title {\n  font-size: 16px;\n}\n\n.as-code-feedback-text-area {\n  min-height: 70px;\n  height: 70px;\n  align-items: center;\n  display: flex;\n  background: #f5faf6;\n  border: 1px solid #b1d2aa;\n  border-radius: 4px;\n  padding: 6px 5px 3px 10px;\n  margin-bottom: 5px;\n}\n\n.as-code-feedback-text-area textarea {\n  background: inherit;\n}\n\n.as-code-feedback-form {\n}\n\n.as-code-feedback-button-container {\n  display: flex;\n  justify-content: flex-end;\n}\n\n.as-code-feedback-submit-button {\n  border: none;\n  font-size: 12px;\n  background: #4fab4f;\n  border-radius: 4px;\n  padding-left: 12px;\n  padding-right: 12px;\n  margin-top: 5px;\n  height: 32px;\n  color: white;\n  cursor: pointer;\n}\n\n.as-code-feedback-submit-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-settings-container {\n  display: flex;\n  flex-direction: column;\n  margin-top: 20px;\n  margin-bottom: 40px;\n  overflow-y: scroll;\n}\n\n.as-setting-control-container {\n  border-bottom: 1px solid rgba(85, 85, 85, 0.05);\n  padding: 20px;\n  height: -webkit-fill-available;\n  overflow-y: scroll;\n}\n\n.as-setting-control-title {\n  font-size: 14px;\n  font-weight: bold;\n  margin-bottom: 10px;\n}\n\n.as-setting-control-inner-container {\n  display: flex;\n  align-items: center;\n  justify-content: end;\n  gap: 20px;\n  font-size: 13px;\n  margin: 20px 0;\n}\n\n.as-setting-control-description {\n  max-width: 77%;\n}\n\n.as-settings-template-container {\n  padding-top: 20px;\n}\n\n.as-settings-sub-header-container {\n  font-size: 12px;\n  font-weight: lighter;\n  color: #9ca3af;\n  margin-bottom: 25px;\n  display: flex;\n  flex-direction: column;\n}\n\n.as-settings-sub-header {\n}\n\n.as-setting-container {\n  display: flex;\n  flex-direction: column;\n  margin-bottom: 20px;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit {\n  max-width: 100%;\n  flex-grow: 1;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit\n  svg {\n  width: 12px;\n  margin-right: 4px;\n  display: inline-block;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit\n  .as-code-upgrade-button {\n  align-items: center;\n  background: #4fab4f;\n  border-radius: 4px;\n  border: none;\n  color: white;\n  cursor: pointer;\n  display: flex;\n  font-size: 16px;\n  font-style: normal;\n  justify-content: center;\n  margin-bottom: 5px;\n  margin-top: 15px;\n  margin-left: auto;\n  margin-right: 20px;\n  padding: 8px;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit\n  .as-code-upgrade-button:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-setting-control-description.as-setting-logout {\n  max-width: 100%;\n}\n\n.as-setting-control-description .as-logout-button {\n  color: #444;\n  align-items: center;\n  border-radius: 4px;\n  border: none;\n  cursor: pointer;\n  display: flex;\n  font-size: 16px;\n  font-style: normal;\n  justify-content: center;\n  padding: 8px;\n}\n\n.as-setting-control-description.as-setting-control-description-context-limit a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-code-run-button,\n.as-code-replace-button,\n.as-code-copy-button {\n  display: flex;\n  border: none;\n  background: #e9e6fe;\n  color: #6c5af6;\n  justify-content: center;\n  align-items: center;\n  border-radius: 4px;\n  font-size: 13px;\n  font-weight: 400;\n  font-style: normal;\n  padding: 8px;\n  cursor: pointer;\n  transition: 0.5s ease-out;\n  -moz-transition: 0.5s ease-out;\n  -webkit-transition: 0.5s ease-out;\n}\n\n.as-code-run-button.disabled,\n.as-code-replace-button.disabled,\n.as-code-copy-button.disabled {\n  background: #f5f5f5;\n  color: #999;\n  cursor: not-allowed;\n}\n\n.as-code-copy-button {\n  margin-left: auto;\n}\n.as-code-run-button.clicked,\n.as-code-replace-button.clicked,\n.as-code-copy-button.clicked {\n  background: rgba(67, 176, 73, 0.5);\n  color: black;\n}\n\n.as-code-run-button:hover:not(.clicked):not(.disabled),\n.as-code-replace-button:hover:not(.clicked):not(.disabled),\n.as-code-copy-button:hover:not(.clicked):not(.disabled) {\n  background: #e1ddfd;\n}\n\n.as-code-replace-button {\n  flex-grow: 1;\n}\n\n.as-run-code-container {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  padding-left: 20px;\n  padding-right: 20px;\n  min-height: 16px;\n  margin-bottom: 8px;\n  gap: 10px;\n}\n\n.as-access-inner-container {\n  padding: 0px 20px 0px 20px;\n}\n\n.as-access-inner-container-buttons {\n  padding: 0px 20px 0px 20px;\n  display: flex;\n  justify-content: space-between;\n}\n\n.as-access-header {\n  font-size: 24px;\n  font-weight: lighter;\n  margin-bottom: 10px;\n  margin-top: 10px;\n  font-family: \"Inter\", sans-serif;\n}\n\n.as-access-text {\n  font-size: 13px;\n  font-weight: normal;\n}\n\n.as-access-inner-container a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-terms-button,\n.as-access-button,\n.as-access-inner-container-buttons .as-logout-button {\n  margin-top: 35px;\n  border-radius: 4px;\n  padding: 12px;\n  background: #4fab4f;\n  border: none;\n  color: white;\n  cursor: pointer;\n  font-size: 16px;\n}\n\n.as-terms-button {\n  margin-left: auto;\n}\n\n\n.as-terms-button:hover {\n  background: #0cca4a;\n  color: black;\n}\n\n.as-terms-error-button {\n  border-radius: 4px;\n  padding: 12px;\n  background: #3874cb;\n  border: none;\n  color: white;\n  cursor: pointer;\n}\n\n.as-terms-error {\n  border-radius: 6px;\n  /* Transparent red */\n  background-color: rgba(255, 0, 0, 0.1);\n  padding: 10px;\n  font-size: 12px;\n}\n\n.as-terms-error-text {\n  color: #ff0000;\n  font-size: 12px;\n  margin-bottom: 10px;\n}\n\n.as-sub-header-container {\n  height: 40px;\n  min-height: 40px;\n  display: flex;\n  align-items: center;\n  border-bottom: 1px solid #d9d9d9;\n  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.07);\n}\n\n.as-sub-header-container.as-has-previous-chat {\n  border-bottom: none;\n  box-shadow: none;\n}\n\n.as-sub-header-menu-icon-wrapper {\n  display: flex;\n  align-items: center;\n  margin-left: 17px;\n  font-size: 12px;\n  color: #6a718a;\n  cursor: pointer;\n  user-select: none;\n  -webkit-user-select: none;\n}\n\n.as-sub-header-menu-icon {\n  width: 14px;\n  margin-top: 3px;\n  margin-right: 8px;\n}\n\n.as-sub-header-title-container {\n  display: flex;\n  flex: 1;\n  justify-content: center;\n  align-items: center;\n}\n\n.as-sub-header-title {\n  font-size: 13px;\n}\n\n.as-sub-header-new-chat-icon-wrapper {\n  display: flex;\n  align-items: center;\n  font-size: 12px;\n  margin-right: 15px;\n  padding: 5px 12px;\n  border-radius: 4px;\n  background: #4fab4f;\n  color: white;\n  cursor: pointer;\n  user-select: none;\n  -webkit-user-select: none;\n}\n\n.as-sub-header-new-chat-icon-wrapper:hover {\n  background: #0cca4a;\n  color: #06262d;\n}\n\n.as-sub-header-new-chat-icon-wrapper.disabled {\n  background: #43b04933;\n  color: #31a824;\n  cursor: default;\n}\n\n.as-sub-header-new-chat-icon {\n  width: 14px;\n  padding-right: 7px;\n}\n\n.as-sub-header-link-text {\n  font-size: 13px;\n  color: #6a718a;\n}\n\n.as-sub-header-link-text a {\n  color: #6c5af6;\n  text-decoration: underline;\n}\n\n.as-back-button-container {\n  background-color: #e9e6fe;\n  height: 30px;\n  padding: 0 18px;\n  display: flex;\n  align-items: center;\n  border-bottom: 1px solid #d9d9d9;\n  color: #778;\n}\n\n.as-back-button-icon {\n  width: 14px;\n  padding-top: 4px;\n  padding-left: 2px;\n  padding-right: 2px;\n  color: #6c5af6;\n  cursor: pointer;\n}\n\n.as-back-button-title-container {\n  width: 100%;\n  display: grid;\n  text-align: center;\n}\n\n.as-back-button-title {\n  font-size: 12px;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  min-width: 0;\n}\n\n.as-generate-code-option-container {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  border: 1px solid #e0e0e0;\n  border-radius: 4px;\n  padding: 12px;\n  margin-bottom: 8px;\n  cursor: pointer;\n}\n.as-generate-code-option-container:hover {\n  background: rgba(33, 33, 33, 0.05);\n}\n\n.as-menu-drawer-container {\n  z-index: 10;\n  position: absolute;\n}\n\n.as-menu-background {\n  position: absolute;\n  top: 90px;\n  background: gray;\n  transition: opacity 0.5s ease-in-out;\n  height: 100vh;\n}\n\n.as-menu-drawer {\n  position: absolute;\n  height: calc(100vh - 90px);\n  background: white;\n  opacity: 1;\n  border-right: 1px solid #999;\n}\n\n.as-menu-drawer.open {\n  box-shadow: 4px 0 8px rgba(0, 0, 0, 0.1);\n}\n\n.as-history-menu {\n  padding-left: 10px;\n  padding-right: 10px;\n  font-size: 14px;\n  height: 100%;\n  z-index: 10;\n}\n.as-history-menu-header {\n  margin-top: 12px;\n  margin-bottom: 12px;\n  margin-left: 10px;\n  font-size: 14px;\n  color: rgb(33, 33, 33, 0.5);\n}\n.as-history-menu-container {\n  display: flex;\n  flex-direction: column;\n}\n.as-history-menu-item {\n  height: 40px;\n  border-radius: 8px;\n  display: flex;\n  align-items: center;\n  padding-left: 10px;\n  padding-right: 10px;\n  margin-bottom: 5px;\n}\n.as-history-menu-item-active {\n  background: #43b0491f;\n}\n\n.as-history-menu-item:hover {\n  background: #f3f4f6;\n  cursor: pointer;\n}\n\n.as-history-menu-item-icon {\n  width: 13px;\n  height: 13px;\n  min-width: 13px;\n  margin-top: 2px;\n  margin-right: 8px;\n  color: #43b049;\n}\n\n.as-history-menu-item-text {\n  overflow: hidden;\n  font-size: 13px;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n}\n\n.as-history-menu-item-close-icon {\n  height: 13px;\n  color: #6a718a;\n  cursor: pointer;\n  display: none;\n  margin-left: auto;\n}\n\n.as-history-menu-item-close-icon svg {\n  width: 10px;\n}\n\n.as-history-menu-item:hover .as-history-menu-item-close-icon {\n  display: block;\n}\n\n.as-history-no-chats {\n  height: calc(100% - 100px);\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  justify-content: center;\n  font-size: 14px;\n  color: rgb(33, 33, 33, 0.3);\n}\n\n.as-popup-outer-container {\n  position: fixed;\n  width: 480px;\n  right: 32px;\n  bottom: 80px;\n}\n\n.as-error-popup {\n  position: absolute;\n  border: 2px solid rgba(219, 105, 112, 0.4);\n  box-shadow: 0 0 16px rgba(0, 0, 0, 0.1);\n  border-radius: 8px;\n  background: white;\n  z-index: 1;\n}\n\n.as-explain-popup {\n  position: absolute;\n  border: 1px solid rgba(224, 224, 224, 0.8);\n  box-shadow: 0 0 16px rgba(0, 0, 0, 0.1);\n  border-radius: 8px;\n  background: white;\n  z-index: 1;\n}\n\n.as-popup-container {\n  padding: 0 16px;\n  height: 100%;\n  display: flex;\n  flex-direction: column;\n}\n\n.as-popup-header {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  font-size: 13px;\n  font-weight: bold;\n  padding-top: 10px;\n  padding-bottom: 10px;\n  color: #212121;\n}\n\n.as-popup-logo {\n  display: flex;\n  align-items: center;\n  color: #2c303a;\n  font-style: normal;\n  font-weight: 700;\n  font-size: 14px;\n}\n\n.as-popup-icon-container {\n  background: #4fab4f;\n  border-radius: 4px;\n  margin-right: 10px;\n  padding: 8px 4px 5px 4px;\n}\n\n.as-popup-icon {\n  width: 20px;\n  height: 16px;\n  color: white;\n}\n\n.as-popup-close-icon {\n  width: 14px;\n  color: rgb(33, 33, 33, 0.5);\n  cursor: pointer;\n}\n\n.as-popup-close-icon:hover {\n  color: rgb(33, 33, 33, 0.8);\n}\n\n.as-popup-buttons {\n  display: flex;\n  flex-direction: column;\n  gap: 5px;\n  padding-bottom: 15px;\n}\n\n.as-popup-button {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  background: white;\n  border: 1px solid #e6e6e6;\n  margin-bottom: 3px;\n  border-radius: 8px;\n  padding: 9px 12px 9px 12px;\n  cursor: pointer;\n}\n\n.as-popup-button:hover {\n  background: rgba(33, 33, 33, 0.05);\n}\n\n.as-popup-button-icon {\n  width: 8px;\n  height: 12px;\n  color: rgba(33, 33, 33, 0.5);\n}\n\n.as-popup-buttons-section {\n  display: flex;\n  align-items: center;\n  font-size: 13px;\n  font-weight: 590;\n  letter-spacing: 0.02em;\n}\n"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),

/***/ "./style/base.css":
/*!************************!*\
  !*** ./style/base.css ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! !../../../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js */ "../../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js");
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! !!../../../node_modules/css-loader/dist/cjs.js!./base.css */ "../../node_modules/css-loader/dist/cjs.js!./style/base.css");

            

var options = {};

options.insert = "head";
options.singleton = false;

var update = _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default()(_node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__["default"], options);



/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__["default"].locals || {});

/***/ }),

/***/ "../../lib/assistant/lib/style/base.css":
/*!**********************************************!*\
  !*** ../../lib/assistant/lib/style/base.css ***!
  \**********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! !../../../../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js */ "../../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js");
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! !!../../../../node_modules/css-loader/dist/cjs.js!./base.css */ "../../node_modules/css-loader/dist/cjs.js!../../lib/assistant/lib/style/base.css");

            

var options = {};

options.insert = "head";
options.singleton = false;

var update = _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default()(_node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__["default"], options);



/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_node_modules_css_loader_dist_cjs_js_base_css__WEBPACK_IMPORTED_MODULE_1__["default"].locals || {});

/***/ })

}]);
//# sourceMappingURL=style_index_js.37aeb4ffe56b127ccaab.js.map